'''OpenGL extension SGIS.detail_texture

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_SGIS_detail_texture'
_DEPRECATED = False
GL_DETAIL_TEXTURE_2D_SGIS = constant.Constant( 'GL_DETAIL_TEXTURE_2D_SGIS', 0x8095 )
GL_DETAIL_TEXTURE_2D_BINDING_SGIS = constant.Constant( 'GL_DETAIL_TEXTURE_2D_BINDING_SGIS', 0x8096 )
GL_LINEAR_DETAIL_SGIS = constant.Constant( 'GL_LINEAR_DETAIL_SGIS', 0x8097 )
GL_LINEAR_DETAIL_ALPHA_SGIS = constant.Constant( 'GL_LINEAR_DETAIL_ALPHA_SGIS', 0x8098 )
GL_LINEAR_DETAIL_COLOR_SGIS = constant.Constant( 'GL_LINEAR_DETAIL_COLOR_SGIS', 0x8099 )
GL_DETAIL_TEXTURE_LEVEL_SGIS = constant.Constant( 'GL_DETAIL_TEXTURE_LEVEL_SGIS', 0x809A )
GL_DETAIL_TEXTURE_MODE_SGIS = constant.Constant( 'GL_DETAIL_TEXTURE_MODE_SGIS', 0x809B )
GL_DETAIL_TEXTURE_FUNC_POINTS_SGIS = constant.Constant( 'GL_DETAIL_TEXTURE_FUNC_POINTS_SGIS', 0x809C )
glDetailTexFuncSGIS = platform.createExtensionFunction( 
'glDetailTexFuncSGIS',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLsizei,arrays.GLfloatArray,),
doc='glDetailTexFuncSGIS(GLenum(target), GLsizei(n), GLfloatArray(points)) -> None',
argNames=('target','n','points',),
deprecated=_DEPRECATED,
)

glGetDetailTexFuncSGIS = platform.createExtensionFunction( 
'glGetDetailTexFuncSGIS',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,arrays.GLfloatArray,),
doc='glGetDetailTexFuncSGIS(GLenum(target), GLfloatArray(points)) -> None',
argNames=('target','points',),
deprecated=_DEPRECATED,
)


def glInitDetailTextureSGIS():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension NV.register_combiners2

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_NV_register_combiners2'
_DEPRECATED = False
GL_PER_STAGE_CONSTANTS_NV = constant.Constant( 'GL_PER_STAGE_CONSTANTS_NV', 0x8535 )
glget.addGLGetConstant( GL_PER_STAGE_CONSTANTS_NV, (1,) )
glCombinerStageParameterfvNV = platform.createExtensionFunction( 
'glCombinerStageParameterfvNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,arrays.GLfloatArray,),
doc='glCombinerStageParameterfvNV(GLenum(stage), GLenum(pname), GLfloatArray(params)) -> None',
argNames=('stage','pname','params',),
deprecated=_DEPRECATED,
)

glGetCombinerStageParameterfvNV = platform.createExtensionFunction( 
'glGetCombinerStageParameterfvNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,arrays.GLfloatArray,),
doc='glGetCombinerStageParameterfvNV(GLenum(stage), GLenum(pname), GLfloatArray(params)) -> None',
argNames=('stage','pname','params',),
deprecated=_DEPRECATED,
)


def glInitRegisterCombiners2NV():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension ARB.matrix_palette

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_ARB_matrix_palette'
_DEPRECATED = False
GL_MATRIX_PALETTE_ARB = constant.Constant( 'GL_MATRIX_PALETTE_ARB', 0x8840 )
GL_MAX_MATRIX_PALETTE_STACK_DEPTH_ARB = constant.Constant( 'GL_MAX_MATRIX_PALETTE_STACK_DEPTH_ARB', 0x8841 )
glget.addGLGetConstant( GL_MAX_MATRIX_PALETTE_STACK_DEPTH_ARB, (1,) )
GL_MAX_PALETTE_MATRICES_ARB = constant.Constant( 'GL_MAX_PALETTE_MATRICES_ARB', 0x8842 )
glget.addGLGetConstant( GL_MAX_PALETTE_MATRICES_ARB, (1,) )
GL_CURRENT_PALETTE_MATRIX_ARB = constant.Constant( 'GL_CURRENT_PALETTE_MATRIX_ARB', 0x8843 )
GL_MATRIX_INDEX_ARRAY_ARB = constant.Constant( 'GL_MATRIX_INDEX_ARRAY_ARB', 0x8844 )
GL_CURRENT_MATRIX_INDEX_ARB = constant.Constant( 'GL_CURRENT_MATRIX_INDEX_ARB', 0x8845 )
GL_MATRIX_INDEX_ARRAY_SIZE_ARB = constant.Constant( 'GL_MATRIX_INDEX_ARRAY_SIZE_ARB', 0x8846 )
glget.addGLGetConstant( GL_MATRIX_INDEX_ARRAY_SIZE_ARB, (1,) )
GL_MATRIX_INDEX_ARRAY_TYPE_ARB = constant.Constant( 'GL_MATRIX_INDEX_ARRAY_TYPE_ARB', 0x8847 )
glget.addGLGetConstant( GL_MATRIX_INDEX_ARRAY_TYPE_ARB, (1,) )
GL_MATRIX_INDEX_ARRAY_STRIDE_ARB = constant.Constant( 'GL_MATRIX_INDEX_ARRAY_STRIDE_ARB', 0x8848 )
glget.addGLGetConstant( GL_MATRIX_INDEX_ARRAY_STRIDE_ARB, (1,) )
GL_MATRIX_INDEX_ARRAY_POINTER_ARB = constant.Constant( 'GL_MATRIX_INDEX_ARRAY_POINTER_ARB', 0x8849 )
glCurrentPaletteMatrixARB = platform.createExtensionFunction( 
'glCurrentPaletteMatrixARB',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLint,),
doc='glCurrentPaletteMatrixARB(GLint(index)) -> None',
argNames=('index',),
deprecated=_DEPRECATED,
)

glMatrixIndexubvARB = platform.createExtensionFunction( 
'glMatrixIndexubvARB',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLint,arrays.GLubyteArray,),
doc='glMatrixIndexubvARB(GLint(size), GLubyteArray(indices)) -> None',
argNames=('size','indices',),
deprecated=_DEPRECATED,
)

glMatrixIndexusvARB = platform.createExtensionFunction( 
'glMatrixIndexusvARB',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLint,arrays.GLushortArray,),
doc='glMatrixIndexusvARB(GLint(size), GLushortArray(indices)) -> None',
argNames=('size','indices',),
deprecated=_DEPRECATED,
)

glMatrixIndexuivARB = platform.createExtensionFunction( 
'glMatrixIndexuivARB',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLint,arrays.GLuintArray,),
doc='glMatrixIndexuivARB(GLint(size), GLuintArray(indices)) -> None',
argNames=('size','indices',),
deprecated=_DEPRECATED,
)

glMatrixIndexPointerARB = platform.createExtensionFunction( 
'glMatrixIndexPointerARB',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLint,constants.GLenum,constants.GLsizei,ctypes.c_void_p,),
doc='glMatrixIndexPointerARB(GLint(size), GLenum(type), GLsizei(stride), c_void_p(pointer)) -> None',
argNames=('size','type','stride','pointer',),
deprecated=_DEPRECATED,
)


def glInitMatrixPaletteARB():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension VERSION.GL_1_2

This module customises the behaviour of the 
OpenGL.raw.GL.VERSION.GL_1_2 to provide a more 
Python-friendly API

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/VERSION/GL_1_2.txt
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions, wrapper
from OpenGL.GL import glget
import ctypes
from OpenGL.raw.GL.VERSION.GL_1_2 import *
### END AUTOGENERATED SECTION
from OpenGL.GL.VERSION.GL_1_2_images import *

glDrawRangeElements = wrapper.wrapper( simple.glDrawRangeElements ).setPyConverter(
    'indices', arrays.AsArrayOfType( 'indices', 'type' ),
).setReturnValues(
    wrapper.returnPyArgument( 'indices' )
)


'''OpenGL extension REND.screen_coordinates

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_REND_screen_coordinates'
_DEPRECATED = False
GL_SCREEN_COORDINATES_REND = constant.Constant( 'GL_SCREEN_COORDINATES_REND', 0x8490 )
GL_INVERTED_SCREEN_W_REND = constant.Constant( 'GL_INVERTED_SCREEN_W_REND', 0x8491 )


def glInitScreenCoordinatesREND():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension NV.fog_distance

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_NV_fog_distance'
_DEPRECATED = False
GL_FOG_DISTANCE_MODE_NV = constant.Constant( 'GL_FOG_DISTANCE_MODE_NV', 0x855A )
glget.addGLGetConstant( GL_FOG_DISTANCE_MODE_NV, (1,) )
GL_EYE_RADIAL_NV = constant.Constant( 'GL_EYE_RADIAL_NV', 0x855B )
GL_EYE_PLANE_ABSOLUTE_NV = constant.Constant( 'GL_EYE_PLANE_ABSOLUTE_NV', 0x855C )


def glInitFogDistanceNV():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



#! /usr/bin/env python
"""Do a lot of hacking about to find glGet-able constants..."""
from OpenGL import constant, error
from OpenGL.raw import GL
from OpenGLContext import testingcontext
BaseContext = testingcontext.getInteractive()
from OpenGLContext import arrays
from OpenGL.GL import glget
import sys

class TestContext( BaseContext ):
    def OnInit( self ):
        """Do our testing here..."""
        weird_value = -701496917
        data = arrays.zeros( (256,),'i')
        for name in dir( GL ):
            value = getattr( GL, name )
            if isinstance( value, constant.Constant ):
                if value in glget.GL_GET_SIZES:
                    continue
                data[:] = weird_value
                try:
                    GL.glGetIntegerv(
                        value,
                        data 
                    )
                except error.GLError, err:
                    if err.err == 1280:
                        print '# No: %s'%( value.name, )
                    else:
                        print 'simple.%s: (1,), # TODO: Check size!'%( value.name, )
                else:
                    ordinality = 256 - arrays.sum( 
                        (data == weird_value)
                    )
                    if ordinality == 16:
                        ordinality = (4,4)
                    else:
                        ordinality = (ordinality,)
                    print 'simple.%s: %s,'%(value.name,ordinality)
        sys.exit( 0)

if __name__ == "__main__":
    TestContext.ContextMainLoop()
    



'''OpenGL extension SGIX.instruments

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_SGIX_instruments'
_DEPRECATED = False
GL_INSTRUMENT_BUFFER_POINTER_SGIX = constant.Constant( 'GL_INSTRUMENT_BUFFER_POINTER_SGIX', 0x8180 )
GL_INSTRUMENT_MEASUREMENTS_SGIX = constant.Constant( 'GL_INSTRUMENT_MEASUREMENTS_SGIX', 0x8181 )
glGetInstrumentsSGIX = platform.createExtensionFunction( 
'glGetInstrumentsSGIX',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=constants.GLint, 
argTypes=(),
doc='glGetInstrumentsSGIX() -> constants.GLint',
argNames=(),
deprecated=_DEPRECATED,
)

glInstrumentsBufferSGIX = platform.createExtensionFunction( 
'glInstrumentsBufferSGIX',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLsizei,arrays.GLintArray,),
doc='glInstrumentsBufferSGIX(GLsizei(size), GLintArray(buffer)) -> None',
argNames=('size','buffer',),
deprecated=_DEPRECATED,
)

glPollInstrumentsSGIX = platform.createExtensionFunction( 
'glPollInstrumentsSGIX',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=constants.GLint, 
argTypes=(arrays.GLintArray,),
doc='glPollInstrumentsSGIX(GLintArray(marker_p)) -> constants.GLint',
argNames=('marker_p',),
deprecated=_DEPRECATED,
)

glReadInstrumentsSGIX = platform.createExtensionFunction( 
'glReadInstrumentsSGIX',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLint,),
doc='glReadInstrumentsSGIX(GLint(marker)) -> None',
argNames=('marker',),
deprecated=_DEPRECATED,
)

glStartInstrumentsSGIX = platform.createExtensionFunction( 
'glStartInstrumentsSGIX',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(),
doc='glStartInstrumentsSGIX() -> None',
argNames=(),
deprecated=_DEPRECATED,
)

glStopInstrumentsSGIX = platform.createExtensionFunction( 
'glStopInstrumentsSGIX',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLint,),
doc='glStopInstrumentsSGIX(GLint(marker)) -> None',
argNames=('marker',),
deprecated=_DEPRECATED,
)


def glInitInstrumentsSGIX():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension NV.parameter_buffer_object

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_NV_parameter_buffer_object'
_DEPRECATED = False
GL_MAX_PROGRAM_PARAMETER_BUFFER_BINDINGS_NV = constant.Constant( 'GL_MAX_PROGRAM_PARAMETER_BUFFER_BINDINGS_NV', 0x8DA0 )
GL_MAX_PROGRAM_PARAMETER_BUFFER_SIZE_NV = constant.Constant( 'GL_MAX_PROGRAM_PARAMETER_BUFFER_SIZE_NV', 0x8DA1 )
GL_VERTEX_PROGRAM_PARAMETER_BUFFER_NV = constant.Constant( 'GL_VERTEX_PROGRAM_PARAMETER_BUFFER_NV', 0x8DA2 )
glget.addGLGetConstant( GL_VERTEX_PROGRAM_PARAMETER_BUFFER_NV, (1,) )
GL_GEOMETRY_PROGRAM_PARAMETER_BUFFER_NV = constant.Constant( 'GL_GEOMETRY_PROGRAM_PARAMETER_BUFFER_NV', 0x8DA3 )
GL_FRAGMENT_PROGRAM_PARAMETER_BUFFER_NV = constant.Constant( 'GL_FRAGMENT_PROGRAM_PARAMETER_BUFFER_NV', 0x8DA4 )
glProgramBufferParametersfvNV = platform.createExtensionFunction( 
'glProgramBufferParametersfvNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,constants.GLuint,constants.GLsizei,arrays.GLfloatArray,),
doc='glProgramBufferParametersfvNV(GLenum(target), GLuint(buffer), GLuint(index), GLsizei(count), GLfloatArray(params)) -> None',
argNames=('target','buffer','index','count','params',),
deprecated=_DEPRECATED,
)

glProgramBufferParametersIivNV = platform.createExtensionFunction( 
'glProgramBufferParametersIivNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,constants.GLuint,constants.GLsizei,arrays.GLintArray,),
doc='glProgramBufferParametersIivNV(GLenum(target), GLuint(buffer), GLuint(index), GLsizei(count), GLintArray(params)) -> None',
argNames=('target','buffer','index','count','params',),
deprecated=_DEPRECATED,
)

glProgramBufferParametersIuivNV = platform.createExtensionFunction( 
'glProgramBufferParametersIuivNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,constants.GLuint,constants.GLsizei,arrays.GLuintArray,),
doc='glProgramBufferParametersIuivNV(GLenum(target), GLuint(buffer), GLuint(index), GLsizei(count), GLuintArray(params)) -> None',
argNames=('target','buffer','index','count','params',),
deprecated=_DEPRECATED,
)


def glInitParameterBufferObjectNV():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension SGIS.texture_lod

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_SGIS_texture_lod'
_DEPRECATED = False
GL_TEXTURE_MIN_LOD_SGIS = constant.Constant( 'GL_TEXTURE_MIN_LOD_SGIS', 0x813A )
GL_TEXTURE_MAX_LOD_SGIS = constant.Constant( 'GL_TEXTURE_MAX_LOD_SGIS', 0x813B )
GL_TEXTURE_BASE_LEVEL_SGIS = constant.Constant( 'GL_TEXTURE_BASE_LEVEL_SGIS', 0x813C )
GL_TEXTURE_MAX_LEVEL_SGIS = constant.Constant( 'GL_TEXTURE_MAX_LEVEL_SGIS', 0x813D )


def glInitTextureLodSGIS():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension S3.s3tc

This module customises the behaviour of the 
OpenGL.raw.GL.S3.s3tc to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension allows specifying texture data in compressed S3TC
	format.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/S3/s3tc.txt
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions, wrapper
from OpenGL.GL import glget
import ctypes
from OpenGL.raw.GL.S3.s3tc import *
### END AUTOGENERATED SECTION


'''OpenGL extension ARB.texture_env_dot3

This module customises the behaviour of the 
OpenGL.raw.GL.ARB.texture_env_dot3 to provide a more 
Python-friendly API

Overview (from the spec)
	
	Adds new operation to the texture combiner operations.
	
	    DOT3_RGB_ARB                    Arg0 <dotprod> Arg1
	    DOT3_RGBA_ARB                   Arg0 <dotprod> Arg1
	
	where Arg0, Arg1 are specified by <params> parameter of 
	TexEnvf, TexEnvi, TexEnvfv, and TexEnviv when the <pname>
	parameter value is SOURCE0_RGB_ARB and SOURCE1_RGB_ARB.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/ARB/texture_env_dot3.txt
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions, wrapper
from OpenGL.GL import glget
import ctypes
from OpenGL.raw.GL.ARB.texture_env_dot3 import *
### END AUTOGENERATED SECTION


'''OpenGL extension MESAX.texture_stack

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_MESAX_texture_stack'
_DEPRECATED = False
GL_TEXTURE_1D_STACK_MESAX = constant.Constant( 'GL_TEXTURE_1D_STACK_MESAX', 0x8759 )
GL_TEXTURE_2D_STACK_MESAX = constant.Constant( 'GL_TEXTURE_2D_STACK_MESAX', 0x875A )
GL_PROXY_TEXTURE_1D_STACK_MESAX = constant.Constant( 'GL_PROXY_TEXTURE_1D_STACK_MESAX', 0x875B )
GL_PROXY_TEXTURE_2D_STACK_MESAX = constant.Constant( 'GL_PROXY_TEXTURE_2D_STACK_MESAX', 0x875C )
GL_TEXTURE_1D_STACK_BINDING_MESAX = constant.Constant( 'GL_TEXTURE_1D_STACK_BINDING_MESAX', 0x875D )
GL_TEXTURE_2D_STACK_BINDING_MESAX = constant.Constant( 'GL_TEXTURE_2D_STACK_BINDING_MESAX', 0x875E )


def glInitTextureStackMESAX():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension .TYPES_DEFINED

The official definition of this extension is available here:
    http://oss.sgi.com/projects/ogl-sample/registry//TYPES_DEFINED.txt

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GLEXT__TYPES_DEFINED'



def glInitTypesDefined():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )


'''OpenGL extension SGIS.multisample

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_SGIS_multisample'
_DEPRECATED = False
GL_MULTISAMPLE_SGIS = constant.Constant( 'GL_MULTISAMPLE_SGIS', 0x809D )
glget.addGLGetConstant( GL_MULTISAMPLE_SGIS, (1,) )
GL_SAMPLE_ALPHA_TO_MASK_SGIS = constant.Constant( 'GL_SAMPLE_ALPHA_TO_MASK_SGIS', 0x809E )
glget.addGLGetConstant( GL_SAMPLE_ALPHA_TO_MASK_SGIS, (1,) )
GL_SAMPLE_ALPHA_TO_ONE_SGIS = constant.Constant( 'GL_SAMPLE_ALPHA_TO_ONE_SGIS', 0x809F )
glget.addGLGetConstant( GL_SAMPLE_ALPHA_TO_ONE_SGIS, (1,) )
GL_SAMPLE_MASK_SGIS = constant.Constant( 'GL_SAMPLE_MASK_SGIS', 0x80A0 )
glget.addGLGetConstant( GL_SAMPLE_MASK_SGIS, (1,) )
GL_1PASS_SGIS = constant.Constant( 'GL_1PASS_SGIS', 0x80A1 )
GL_2PASS_0_SGIS = constant.Constant( 'GL_2PASS_0_SGIS', 0x80A2 )
GL_2PASS_1_SGIS = constant.Constant( 'GL_2PASS_1_SGIS', 0x80A3 )
GL_4PASS_0_SGIS = constant.Constant( 'GL_4PASS_0_SGIS', 0x80A4 )
GL_4PASS_1_SGIS = constant.Constant( 'GL_4PASS_1_SGIS', 0x80A5 )
GL_4PASS_2_SGIS = constant.Constant( 'GL_4PASS_2_SGIS', 0x80A6 )
GL_4PASS_3_SGIS = constant.Constant( 'GL_4PASS_3_SGIS', 0x80A7 )
GL_SAMPLE_BUFFERS_SGIS = constant.Constant( 'GL_SAMPLE_BUFFERS_SGIS', 0x80A8 )
glget.addGLGetConstant( GL_SAMPLE_BUFFERS_SGIS, (1,) )
GL_SAMPLES_SGIS = constant.Constant( 'GL_SAMPLES_SGIS', 0x80A9 )
glget.addGLGetConstant( GL_SAMPLES_SGIS, (1,) )
GL_SAMPLE_MASK_VALUE_SGIS = constant.Constant( 'GL_SAMPLE_MASK_VALUE_SGIS', 0x80AA )
glget.addGLGetConstant( GL_SAMPLE_MASK_VALUE_SGIS, (1,) )
GL_SAMPLE_MASK_INVERT_SGIS = constant.Constant( 'GL_SAMPLE_MASK_INVERT_SGIS', 0x80AB )
glget.addGLGetConstant( GL_SAMPLE_MASK_INVERT_SGIS, (1,) )
GL_SAMPLE_PATTERN_SGIS = constant.Constant( 'GL_SAMPLE_PATTERN_SGIS', 0x80AC )
glget.addGLGetConstant( GL_SAMPLE_PATTERN_SGIS, (1,) )
glSampleMaskSGIS = platform.createExtensionFunction( 
'glSampleMaskSGIS',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLclampf,constants.GLboolean,),
doc='glSampleMaskSGIS(GLclampf(value), GLboolean(invert)) -> None',
argNames=('value','invert',),
deprecated=_DEPRECATED,
)

glSamplePatternSGIS = platform.createExtensionFunction( 
'glSamplePatternSGIS',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,),
doc='glSamplePatternSGIS(GLenum(pattern)) -> None',
argNames=('pattern',),
deprecated=_DEPRECATED,
)


def glInitMultisampleSGIS():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension APPLE.fence

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_APPLE_fence'
_DEPRECATED = False
GL_DRAW_PIXELS_APPLE = constant.Constant( 'GL_DRAW_PIXELS_APPLE', 0x8A0A )
GL_FENCE_APPLE = constant.Constant( 'GL_FENCE_APPLE', 0x8A0B )
glGenFencesAPPLE = platform.createExtensionFunction( 
'glGenFencesAPPLE',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLsizei,arrays.GLuintArray,),
doc='glGenFencesAPPLE(GLsizei(n), GLuintArray(fences)) -> None',
argNames=('n','fences',),
deprecated=_DEPRECATED,
)

glDeleteFencesAPPLE = platform.createExtensionFunction( 
'glDeleteFencesAPPLE',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLsizei,arrays.GLuintArray,),
doc='glDeleteFencesAPPLE(GLsizei(n), GLuintArray(fences)) -> None',
argNames=('n','fences',),
deprecated=_DEPRECATED,
)

glSetFenceAPPLE = platform.createExtensionFunction( 
'glSetFenceAPPLE',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,),
doc='glSetFenceAPPLE(GLuint(fence)) -> None',
argNames=('fence',),
deprecated=_DEPRECATED,
)

glIsFenceAPPLE = platform.createExtensionFunction( 
'glIsFenceAPPLE',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=constants.GLboolean, 
argTypes=(constants.GLuint,),
doc='glIsFenceAPPLE(GLuint(fence)) -> constants.GLboolean',
argNames=('fence',),
deprecated=_DEPRECATED,
)

glTestFenceAPPLE = platform.createExtensionFunction( 
'glTestFenceAPPLE',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=constants.GLboolean, 
argTypes=(constants.GLuint,),
doc='glTestFenceAPPLE(GLuint(fence)) -> constants.GLboolean',
argNames=('fence',),
deprecated=_DEPRECATED,
)

glFinishFenceAPPLE = platform.createExtensionFunction( 
'glFinishFenceAPPLE',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,),
doc='glFinishFenceAPPLE(GLuint(fence)) -> None',
argNames=('fence',),
deprecated=_DEPRECATED,
)

glTestObjectAPPLE = platform.createExtensionFunction( 
'glTestObjectAPPLE',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=constants.GLboolean, 
argTypes=(constants.GLenum,constants.GLuint,),
doc='glTestObjectAPPLE(GLenum(object), GLuint(name)) -> constants.GLboolean',
argNames=('object','name',),
deprecated=_DEPRECATED,
)

glFinishObjectAPPLE = platform.createExtensionFunction( 
'glFinishObjectAPPLE',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLint,),
doc='glFinishObjectAPPLE(GLenum(object), GLint(name)) -> None',
argNames=('object','name',),
deprecated=_DEPRECATED,
)


def glInitFenceAPPLE():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension VERSION.GL_1_5

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_VERSION_GL_1_5'
_DEPRECATED = False
GL_BUFFER_SIZE = constant.Constant( 'GL_BUFFER_SIZE', 0x8764 )
GL_BUFFER_USAGE = constant.Constant( 'GL_BUFFER_USAGE', 0x8765 )
GL_QUERY_COUNTER_BITS = constant.Constant( 'GL_QUERY_COUNTER_BITS', 0x8864 )
GL_CURRENT_QUERY = constant.Constant( 'GL_CURRENT_QUERY', 0x8865 )
GL_QUERY_RESULT = constant.Constant( 'GL_QUERY_RESULT', 0x8866 )
GL_QUERY_RESULT_AVAILABLE = constant.Constant( 'GL_QUERY_RESULT_AVAILABLE', 0x8867 )
GL_ARRAY_BUFFER = constant.Constant( 'GL_ARRAY_BUFFER', 0x8892 )
GL_ELEMENT_ARRAY_BUFFER = constant.Constant( 'GL_ELEMENT_ARRAY_BUFFER', 0x8893 )
GL_ARRAY_BUFFER_BINDING = constant.Constant( 'GL_ARRAY_BUFFER_BINDING', 0x8894 )
GL_ELEMENT_ARRAY_BUFFER_BINDING = constant.Constant( 'GL_ELEMENT_ARRAY_BUFFER_BINDING', 0x8895 )
GL_VERTEX_ATTRIB_ARRAY_BUFFER_BINDING = constant.Constant( 'GL_VERTEX_ATTRIB_ARRAY_BUFFER_BINDING', 0x889F )
GL_READ_ONLY = constant.Constant( 'GL_READ_ONLY', 0x88B8 )
GL_WRITE_ONLY = constant.Constant( 'GL_WRITE_ONLY', 0x88B9 )
GL_READ_WRITE = constant.Constant( 'GL_READ_WRITE', 0x88BA )
GL_BUFFER_ACCESS = constant.Constant( 'GL_BUFFER_ACCESS', 0x88BB )
GL_BUFFER_MAPPED = constant.Constant( 'GL_BUFFER_MAPPED', 0x88BC )
GL_BUFFER_MAP_POINTER = constant.Constant( 'GL_BUFFER_MAP_POINTER', 0x88BD )
GL_STREAM_DRAW = constant.Constant( 'GL_STREAM_DRAW', 0x88E0 )
GL_STREAM_READ = constant.Constant( 'GL_STREAM_READ', 0x88E1 )
GL_STREAM_COPY = constant.Constant( 'GL_STREAM_COPY', 0x88E2 )
GL_STATIC_DRAW = constant.Constant( 'GL_STATIC_DRAW', 0x88E4 )
GL_STATIC_READ = constant.Constant( 'GL_STATIC_READ', 0x88E5 )
GL_STATIC_COPY = constant.Constant( 'GL_STATIC_COPY', 0x88E6 )
GL_DYNAMIC_DRAW = constant.Constant( 'GL_DYNAMIC_DRAW', 0x88E8 )
GL_DYNAMIC_READ = constant.Constant( 'GL_DYNAMIC_READ', 0x88E9 )
GL_DYNAMIC_COPY = constant.Constant( 'GL_DYNAMIC_COPY', 0x88EA )
GL_SAMPLES_PASSED = constant.Constant( 'GL_SAMPLES_PASSED', 0x8914 )
glGenQueries = platform.createExtensionFunction( 
'glGenQueries',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLsizei,arrays.GLuintArray,),
doc='glGenQueries(GLsizei(n), GLuintArray(ids)) -> None',
argNames=('n','ids',),
deprecated=_DEPRECATED,
)

glDeleteQueries = platform.createExtensionFunction( 
'glDeleteQueries',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLsizei,arrays.GLuintArray,),
doc='glDeleteQueries(GLsizei(n), GLuintArray(ids)) -> None',
argNames=('n','ids',),
deprecated=_DEPRECATED,
)

glIsQuery = platform.createExtensionFunction( 
'glIsQuery',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=constants.GLboolean, 
argTypes=(constants.GLuint,),
doc='glIsQuery(GLuint(id)) -> constants.GLboolean',
argNames=('id',),
deprecated=_DEPRECATED,
)

glBeginQuery = platform.createExtensionFunction( 
'glBeginQuery',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,),
doc='glBeginQuery(GLenum(target), GLuint(id)) -> None',
argNames=('target','id',),
deprecated=_DEPRECATED,
)

glEndQuery = platform.createExtensionFunction( 
'glEndQuery',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,),
doc='glEndQuery(GLenum(target)) -> None',
argNames=('target',),
deprecated=_DEPRECATED,
)

glGetQueryiv = platform.createExtensionFunction( 
'glGetQueryiv',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,arrays.GLintArray,),
doc='glGetQueryiv(GLenum(target), GLenum(pname), GLintArray(params)) -> None',
argNames=('target','pname','params',),
deprecated=_DEPRECATED,
)

glGetQueryObjectiv = platform.createExtensionFunction( 
'glGetQueryObjectiv',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,arrays.GLintArray,),
doc='glGetQueryObjectiv(GLuint(id), GLenum(pname), GLintArray(params)) -> None',
argNames=('id','pname','params',),
deprecated=_DEPRECATED,
)

glGetQueryObjectuiv = platform.createExtensionFunction( 
'glGetQueryObjectuiv',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,arrays.GLuintArray,),
doc='glGetQueryObjectuiv(GLuint(id), GLenum(pname), GLuintArray(params)) -> None',
argNames=('id','pname','params',),
deprecated=_DEPRECATED,
)

glBindBuffer = platform.createExtensionFunction( 
'glBindBuffer',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,),
doc='glBindBuffer(GLenum(target), GLuint(buffer)) -> None',
argNames=('target','buffer',),
deprecated=_DEPRECATED,
)

glDeleteBuffers = platform.createExtensionFunction( 
'glDeleteBuffers',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLsizei,arrays.GLuintArray,),
doc='glDeleteBuffers(GLsizei(n), GLuintArray(buffers)) -> None',
argNames=('n','buffers',),
deprecated=_DEPRECATED,
)

glGenBuffers = platform.createExtensionFunction( 
'glGenBuffers',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLsizei,arrays.GLuintArray,),
doc='glGenBuffers(GLsizei(n), GLuintArray(buffers)) -> None',
argNames=('n','buffers',),
deprecated=_DEPRECATED,
)

glIsBuffer = platform.createExtensionFunction( 
'glIsBuffer',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=constants.GLboolean, 
argTypes=(constants.GLuint,),
doc='glIsBuffer(GLuint(buffer)) -> constants.GLboolean',
argNames=('buffer',),
deprecated=_DEPRECATED,
)

glBufferData = platform.createExtensionFunction( 
'glBufferData',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLsizeiptr,ctypes.c_void_p,constants.GLenum,),
doc='glBufferData(GLenum(target), GLsizeiptr(size), c_void_p(data), GLenum(usage)) -> None',
argNames=('target','size','data','usage',),
deprecated=_DEPRECATED,
)

glBufferSubData = platform.createExtensionFunction( 
'glBufferSubData',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLintptr,constants.GLsizeiptr,ctypes.c_void_p,),
doc='glBufferSubData(GLenum(target), GLintptr(offset), GLsizeiptr(size), c_void_p(data)) -> None',
argNames=('target','offset','size','data',),
deprecated=_DEPRECATED,
)

glGetBufferSubData = platform.createExtensionFunction( 
'glGetBufferSubData',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLintptr,constants.GLsizeiptr,ctypes.c_void_p,),
doc='glGetBufferSubData(GLenum(target), GLintptr(offset), GLsizeiptr(size), c_void_p(data)) -> None',
argNames=('target','offset','size','data',),
deprecated=_DEPRECATED,
)

glMapBuffer = platform.createExtensionFunction( 
'glMapBuffer',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=ctypes.c_void_p, 
argTypes=(constants.GLenum,constants.GLenum,),
doc='glMapBuffer(GLenum(target), GLenum(access)) -> ctypes.c_void_p',
argNames=('target','access',),
deprecated=_DEPRECATED,
)

glUnmapBuffer = platform.createExtensionFunction( 
'glUnmapBuffer',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=constants.GLboolean, 
argTypes=(constants.GLenum,),
doc='glUnmapBuffer(GLenum(target)) -> constants.GLboolean',
argNames=('target',),
deprecated=_DEPRECATED,
)

glGetBufferParameteriv = platform.createExtensionFunction( 
'glGetBufferParameteriv',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,arrays.GLintArray,),
doc='glGetBufferParameteriv(GLenum(target), GLenum(pname), GLintArray(params)) -> None',
argNames=('target','pname','params',),
deprecated=_DEPRECATED,
)

glGetBufferPointerv = platform.createExtensionFunction( 
'glGetBufferPointerv',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,ctypes.POINTER(ctypes.c_void_p),),
doc='glGetBufferPointerv(GLenum(target), GLenum(pname), POINTER(ctypes.c_void_p)(params)) -> None',
argNames=('target','pname','params',),
deprecated=_DEPRECATED,
)
# import legacy entry points to allow checking for bool(entryPoint)
from OpenGL.raw.GL.VERSION.GL_1_5_DEPRECATED import *



'''OpenGL extension MESA.resize_buffers

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_MESA_resize_buffers'
_DEPRECATED = False

glResizeBuffersMESA = platform.createExtensionFunction( 
'glResizeBuffersMESA',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(),
doc='glResizeBuffersMESA() -> None',
argNames=(),
deprecated=_DEPRECATED,
)


def glInitResizeBuffersMESA():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension EXT.texture3D

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_EXT_texture3D'
_DEPRECATED = False
GL_PACK_SKIP_IMAGES_EXT = constant.Constant( 'GL_PACK_SKIP_IMAGES_EXT', 0x806B )
glget.addGLGetConstant( GL_PACK_SKIP_IMAGES_EXT, (1,) )
GL_PACK_IMAGE_HEIGHT_EXT = constant.Constant( 'GL_PACK_IMAGE_HEIGHT_EXT', 0x806C )
glget.addGLGetConstant( GL_PACK_IMAGE_HEIGHT_EXT, (1,) )
GL_UNPACK_SKIP_IMAGES_EXT = constant.Constant( 'GL_UNPACK_SKIP_IMAGES_EXT', 0x806D )
glget.addGLGetConstant( GL_UNPACK_SKIP_IMAGES_EXT, (1,) )
GL_UNPACK_IMAGE_HEIGHT_EXT = constant.Constant( 'GL_UNPACK_IMAGE_HEIGHT_EXT', 0x806E )
glget.addGLGetConstant( GL_UNPACK_IMAGE_HEIGHT_EXT, (1,) )
GL_TEXTURE_3D_EXT = constant.Constant( 'GL_TEXTURE_3D_EXT', 0x806F )
glget.addGLGetConstant( GL_TEXTURE_3D_EXT, (1,) )
GL_PROXY_TEXTURE_3D_EXT = constant.Constant( 'GL_PROXY_TEXTURE_3D_EXT', 0x8070 )
GL_TEXTURE_DEPTH_EXT = constant.Constant( 'GL_TEXTURE_DEPTH_EXT', 0x8071 )
GL_TEXTURE_WRAP_R_EXT = constant.Constant( 'GL_TEXTURE_WRAP_R_EXT', 0x8072 )
GL_MAX_3D_TEXTURE_SIZE_EXT = constant.Constant( 'GL_MAX_3D_TEXTURE_SIZE_EXT', 0x8073 )
glget.addGLGetConstant( GL_MAX_3D_TEXTURE_SIZE_EXT, (1,) )
glTexImage3DEXT = platform.createExtensionFunction( 
'glTexImage3DEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLint,constants.GLenum,constants.GLsizei,constants.GLsizei,constants.GLsizei,constants.GLint,constants.GLenum,constants.GLenum,ctypes.c_void_p,),
doc='glTexImage3DEXT(GLenum(target), GLint(level), GLenum(internalformat), GLsizei(width), GLsizei(height), GLsizei(depth), GLint(border), GLenum(format), GLenum(type), c_void_p(pixels)) -> None',
argNames=('target','level','internalformat','width','height','depth','border','format','type','pixels',),
deprecated=_DEPRECATED,
)

glTexSubImage3DEXT = platform.createExtensionFunction( 
'glTexSubImage3DEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLint,constants.GLint,constants.GLint,constants.GLint,constants.GLsizei,constants.GLsizei,constants.GLsizei,constants.GLenum,constants.GLenum,ctypes.c_void_p,),
doc='glTexSubImage3DEXT(GLenum(target), GLint(level), GLint(xoffset), GLint(yoffset), GLint(zoffset), GLsizei(width), GLsizei(height), GLsizei(depth), GLenum(format), GLenum(type), c_void_p(pixels)) -> None',
argNames=('target','level','xoffset','yoffset','zoffset','width','height','depth','format','type','pixels',),
deprecated=_DEPRECATED,
)


def glInitTexture3DEXT():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension SGIX.igloo_interface

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_SGIX_igloo_interface'
_DEPRECATED = False

glIglooInterfaceSGIX = platform.createExtensionFunction( 
'glIglooInterfaceSGIX',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,ctypes.c_void_p,),
doc='glIglooInterfaceSGIX(GLenum(pname), c_void_p(params)) -> None',
argNames=('pname','params',),
deprecated=_DEPRECATED,
)


def glInitIglooInterfaceSGIX():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension EXT.bgra

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_EXT_bgra'
_DEPRECATED = False
GL_BGR_EXT = constant.Constant( 'GL_BGR_EXT', 0x80E0 )
GL_BGRA_EXT = constant.Constant( 'GL_BGRA_EXT', 0x80E1 )


def glInitBgraEXT():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension NV.vertex_array_range

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_NV_vertex_array_range'
_DEPRECATED = False
GL_VERTEX_ARRAY_RANGE_NV = constant.Constant( 'GL_VERTEX_ARRAY_RANGE_NV', 0x851D )
GL_VERTEX_ARRAY_RANGE_LENGTH_NV = constant.Constant( 'GL_VERTEX_ARRAY_RANGE_LENGTH_NV', 0x851E )
glget.addGLGetConstant( GL_VERTEX_ARRAY_RANGE_LENGTH_NV, (1,) )
GL_VERTEX_ARRAY_RANGE_VALID_NV = constant.Constant( 'GL_VERTEX_ARRAY_RANGE_VALID_NV', 0x851F )
glget.addGLGetConstant( GL_VERTEX_ARRAY_RANGE_VALID_NV, (1,) )
GL_MAX_VERTEX_ARRAY_RANGE_ELEMENT_NV = constant.Constant( 'GL_MAX_VERTEX_ARRAY_RANGE_ELEMENT_NV', 0x8520 )
glget.addGLGetConstant( GL_MAX_VERTEX_ARRAY_RANGE_ELEMENT_NV, (1,) )
GL_VERTEX_ARRAY_RANGE_POINTER_NV = constant.Constant( 'GL_VERTEX_ARRAY_RANGE_POINTER_NV', 0x8521 )
glFlushVertexArrayRangeNV = platform.createExtensionFunction( 
'glFlushVertexArrayRangeNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(),
doc='glFlushVertexArrayRangeNV() -> None',
argNames=(),
deprecated=_DEPRECATED,
)

glVertexArrayRangeNV = platform.createExtensionFunction( 
'glVertexArrayRangeNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLsizei,ctypes.c_void_p,),
doc='glVertexArrayRangeNV(GLsizei(length), c_void_p(pointer)) -> None',
argNames=('length','pointer',),
deprecated=_DEPRECATED,
)


def glInitVertexArrayRangeNV():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension NV.video_capture

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_NV_video_capture'
_DEPRECATED = False
GL_VIDEO_BUFFER_NV = constant.Constant( 'GL_VIDEO_BUFFER_NV', 0x9020 )
GL_VIDEO_BUFFER_BINDING_NV = constant.Constant( 'GL_VIDEO_BUFFER_BINDING_NV', 0x9021 )
glget.addGLGetConstant( GL_VIDEO_BUFFER_BINDING_NV, (1,) )
GL_FIELD_UPPER_NV = constant.Constant( 'GL_FIELD_UPPER_NV', 0x9022 )
GL_FIELD_LOWER_NV = constant.Constant( 'GL_FIELD_LOWER_NV', 0x9023 )
GL_NUM_VIDEO_CAPTURE_STREAMS_NV = constant.Constant( 'GL_NUM_VIDEO_CAPTURE_STREAMS_NV', 0x9024 )
GL_NEXT_VIDEO_CAPTURE_BUFFER_STATUS_NV = constant.Constant( 'GL_NEXT_VIDEO_CAPTURE_BUFFER_STATUS_NV', 0x9025 )
GL_VIDEO_CAPTURE_TO_422_SUPPORTED_NV = constant.Constant( 'GL_VIDEO_CAPTURE_TO_422_SUPPORTED_NV', 0x9026 )
GL_LAST_VIDEO_CAPTURE_STATUS_NV = constant.Constant( 'GL_LAST_VIDEO_CAPTURE_STATUS_NV', 0x9027 )
GL_VIDEO_BUFFER_PITCH_NV = constant.Constant( 'GL_VIDEO_BUFFER_PITCH_NV', 0x9028 )
GL_VIDEO_COLOR_CONVERSION_MATRIX_NV = constant.Constant( 'GL_VIDEO_COLOR_CONVERSION_MATRIX_NV', 0x9029 )
GL_VIDEO_COLOR_CONVERSION_MAX_NV = constant.Constant( 'GL_VIDEO_COLOR_CONVERSION_MAX_NV', 0x902A )
GL_VIDEO_COLOR_CONVERSION_MIN_NV = constant.Constant( 'GL_VIDEO_COLOR_CONVERSION_MIN_NV', 0x902B )
GL_VIDEO_COLOR_CONVERSION_OFFSET_NV = constant.Constant( 'GL_VIDEO_COLOR_CONVERSION_OFFSET_NV', 0x902C )
GL_VIDEO_BUFFER_INTERNAL_FORMAT_NV = constant.Constant( 'GL_VIDEO_BUFFER_INTERNAL_FORMAT_NV', 0x902D )
GL_PARTIAL_SUCCESS_NV = constant.Constant( 'GL_PARTIAL_SUCCESS_NV', 0x902E )
GL_SUCCESS_NV = constant.Constant( 'GL_SUCCESS_NV', 0x902F )
GL_FAILURE_NV = constant.Constant( 'GL_FAILURE_NV', 0x9030 )
GL_YCBYCR8_422_NV = constant.Constant( 'GL_YCBYCR8_422_NV', 0x9031 )
GL_YCBAYCR8A_4224_NV = constant.Constant( 'GL_YCBAYCR8A_4224_NV', 0x9032 )
GL_Z6Y10Z6CB10Z6Y10Z6CR10_422_NV = constant.Constant( 'GL_Z6Y10Z6CB10Z6Y10Z6CR10_422_NV', 0x9033 )
GL_Z6Y10Z6CB10Z6A10Z6Y10Z6CR10Z6A10_4224_NV = constant.Constant( 'GL_Z6Y10Z6CB10Z6A10Z6Y10Z6CR10Z6A10_4224_NV', 0x9034 )
GL_Z4Y12Z4CB12Z4Y12Z4CR12_422_NV = constant.Constant( 'GL_Z4Y12Z4CB12Z4Y12Z4CR12_422_NV', 0x9035 )
GL_Z4Y12Z4CB12Z4A12Z4Y12Z4CR12Z4A12_4224_NV = constant.Constant( 'GL_Z4Y12Z4CB12Z4A12Z4Y12Z4CR12Z4A12_4224_NV', 0x9036 )
GL_Z4Y12Z4CB12Z4CR12_444_NV = constant.Constant( 'GL_Z4Y12Z4CB12Z4CR12_444_NV', 0x9037 )
GL_VIDEO_CAPTURE_FRAME_WIDTH_NV = constant.Constant( 'GL_VIDEO_CAPTURE_FRAME_WIDTH_NV', 0x9038 )
GL_VIDEO_CAPTURE_FRAME_HEIGHT_NV = constant.Constant( 'GL_VIDEO_CAPTURE_FRAME_HEIGHT_NV', 0x9039 )
GL_VIDEO_CAPTURE_FIELD_UPPER_HEIGHT_NV = constant.Constant( 'GL_VIDEO_CAPTURE_FIELD_UPPER_HEIGHT_NV', 0x903A )
GL_VIDEO_CAPTURE_FIELD_LOWER_HEIGHT_NV = constant.Constant( 'GL_VIDEO_CAPTURE_FIELD_LOWER_HEIGHT_NV', 0x903B )
GL_VIDEO_CAPTURE_SURFACE_ORIGIN_NV = constant.Constant( 'GL_VIDEO_CAPTURE_SURFACE_ORIGIN_NV', 0x903C )
glBeginVideoCaptureNV = platform.createExtensionFunction( 
'glBeginVideoCaptureNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,),
doc='glBeginVideoCaptureNV(GLuint(video_capture_slot)) -> None',
argNames=('video_capture_slot',),
deprecated=_DEPRECATED,
)

glBindVideoCaptureStreamBufferNV = platform.createExtensionFunction( 
'glBindVideoCaptureStreamBufferNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLuint,constants.GLenum,constants.GLintptrARB,),
doc='glBindVideoCaptureStreamBufferNV(GLuint(video_capture_slot), GLuint(stream), GLenum(frame_region), GLintptrARB(offset)) -> None',
argNames=('video_capture_slot','stream','frame_region','offset',),
deprecated=_DEPRECATED,
)

glBindVideoCaptureStreamTextureNV = platform.createExtensionFunction( 
'glBindVideoCaptureStreamTextureNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLuint,constants.GLenum,constants.GLenum,constants.GLuint,),
doc='glBindVideoCaptureStreamTextureNV(GLuint(video_capture_slot), GLuint(stream), GLenum(frame_region), GLenum(target), GLuint(texture)) -> None',
argNames=('video_capture_slot','stream','frame_region','target','texture',),
deprecated=_DEPRECATED,
)

glEndVideoCaptureNV = platform.createExtensionFunction( 
'glEndVideoCaptureNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,),
doc='glEndVideoCaptureNV(GLuint(video_capture_slot)) -> None',
argNames=('video_capture_slot',),
deprecated=_DEPRECATED,
)

glGetVideoCaptureivNV = platform.createExtensionFunction( 
'glGetVideoCaptureivNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,arrays.GLintArray,),
doc='glGetVideoCaptureivNV(GLuint(video_capture_slot), GLenum(pname), GLintArray(params)) -> None',
argNames=('video_capture_slot','pname','params',),
deprecated=_DEPRECATED,
)

glGetVideoCaptureStreamivNV = platform.createExtensionFunction( 
'glGetVideoCaptureStreamivNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLuint,constants.GLenum,arrays.GLintArray,),
doc='glGetVideoCaptureStreamivNV(GLuint(video_capture_slot), GLuint(stream), GLenum(pname), GLintArray(params)) -> None',
argNames=('video_capture_slot','stream','pname','params',),
deprecated=_DEPRECATED,
)

glGetVideoCaptureStreamfvNV = platform.createExtensionFunction( 
'glGetVideoCaptureStreamfvNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLuint,constants.GLenum,arrays.GLfloatArray,),
doc='glGetVideoCaptureStreamfvNV(GLuint(video_capture_slot), GLuint(stream), GLenum(pname), GLfloatArray(params)) -> None',
argNames=('video_capture_slot','stream','pname','params',),
deprecated=_DEPRECATED,
)

glGetVideoCaptureStreamdvNV = platform.createExtensionFunction( 
'glGetVideoCaptureStreamdvNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLuint,constants.GLenum,arrays.GLdoubleArray,),
doc='glGetVideoCaptureStreamdvNV(GLuint(video_capture_slot), GLuint(stream), GLenum(pname), GLdoubleArray(params)) -> None',
argNames=('video_capture_slot','stream','pname','params',),
deprecated=_DEPRECATED,
)

glVideoCaptureNV = platform.createExtensionFunction( 
'glVideoCaptureNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=constants.GLenum, 
argTypes=(constants.GLuint,arrays.GLuintArray,arrays.GLuint64Array,),
doc='glVideoCaptureNV(GLuint(video_capture_slot), GLuintArray(sequence_num), GLuint64Array(capture_time)) -> constants.GLenum',
argNames=('video_capture_slot','sequence_num','capture_time',),
deprecated=_DEPRECATED,
)

glVideoCaptureStreamParameterivNV = platform.createExtensionFunction( 
'glVideoCaptureStreamParameterivNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLuint,constants.GLenum,arrays.GLintArray,),
doc='glVideoCaptureStreamParameterivNV(GLuint(video_capture_slot), GLuint(stream), GLenum(pname), GLintArray(params)) -> None',
argNames=('video_capture_slot','stream','pname','params',),
deprecated=_DEPRECATED,
)

glVideoCaptureStreamParameterfvNV = platform.createExtensionFunction( 
'glVideoCaptureStreamParameterfvNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLuint,constants.GLenum,arrays.GLfloatArray,),
doc='glVideoCaptureStreamParameterfvNV(GLuint(video_capture_slot), GLuint(stream), GLenum(pname), GLfloatArray(params)) -> None',
argNames=('video_capture_slot','stream','pname','params',),
deprecated=_DEPRECATED,
)

glVideoCaptureStreamParameterdvNV = platform.createExtensionFunction( 
'glVideoCaptureStreamParameterdvNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLuint,constants.GLenum,arrays.GLdoubleArray,),
doc='glVideoCaptureStreamParameterdvNV(GLuint(video_capture_slot), GLuint(stream), GLenum(pname), GLdoubleArray(params)) -> None',
argNames=('video_capture_slot','stream','pname','params',),
deprecated=_DEPRECATED,
)


def glInitVideoCaptureNV():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension SGIS.point_line_texgen

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_SGIS_point_line_texgen'
_DEPRECATED = False
GL_EYE_DISTANCE_TO_POINT_SGIS = constant.Constant( 'GL_EYE_DISTANCE_TO_POINT_SGIS', 0x81F0 )
GL_OBJECT_DISTANCE_TO_POINT_SGIS = constant.Constant( 'GL_OBJECT_DISTANCE_TO_POINT_SGIS', 0x81F1 )
GL_EYE_DISTANCE_TO_LINE_SGIS = constant.Constant( 'GL_EYE_DISTANCE_TO_LINE_SGIS', 0x81F2 )
GL_OBJECT_DISTANCE_TO_LINE_SGIS = constant.Constant( 'GL_OBJECT_DISTANCE_TO_LINE_SGIS', 0x81F3 )
GL_EYE_POINT_SGIS = constant.Constant( 'GL_EYE_POINT_SGIS', 0x81F4 )
GL_OBJECT_POINT_SGIS = constant.Constant( 'GL_OBJECT_POINT_SGIS', 0x81F5 )
GL_EYE_LINE_SGIS = constant.Constant( 'GL_EYE_LINE_SGIS', 0x81F6 )
GL_OBJECT_LINE_SGIS = constant.Constant( 'GL_OBJECT_LINE_SGIS', 0x81F7 )


def glInitPointLineTexgenSGIS():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension EXT.texture_compression_s3tc

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_EXT_texture_compression_s3tc'
_DEPRECATED = False
GL_COMPRESSED_RGB_S3TC_DXT1_EXT = constant.Constant( 'GL_COMPRESSED_RGB_S3TC_DXT1_EXT', 0x83F0 )
GL_COMPRESSED_RGBA_S3TC_DXT1_EXT = constant.Constant( 'GL_COMPRESSED_RGBA_S3TC_DXT1_EXT', 0x83F1 )
GL_COMPRESSED_RGBA_S3TC_DXT3_EXT = constant.Constant( 'GL_COMPRESSED_RGBA_S3TC_DXT3_EXT', 0x83F2 )
GL_COMPRESSED_RGBA_S3TC_DXT5_EXT = constant.Constant( 'GL_COMPRESSED_RGBA_S3TC_DXT5_EXT', 0x83F3 )


def glInitTextureCompressionS3TcEXT():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension VERSION.GL_1_5_DEPRECATED

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_VERSION_GL_1_5'
_DEPRECATED = True
GL_VERTEX_ARRAY_BUFFER_BINDING = constant.Constant( 'GL_VERTEX_ARRAY_BUFFER_BINDING', 0x8896 )
GL_NORMAL_ARRAY_BUFFER_BINDING = constant.Constant( 'GL_NORMAL_ARRAY_BUFFER_BINDING', 0x8897 )
GL_COLOR_ARRAY_BUFFER_BINDING = constant.Constant( 'GL_COLOR_ARRAY_BUFFER_BINDING', 0x8898 )
GL_INDEX_ARRAY_BUFFER_BINDING = constant.Constant( 'GL_INDEX_ARRAY_BUFFER_BINDING', 0x8899 )
GL_TEXTURE_COORD_ARRAY_BUFFER_BINDING = constant.Constant( 'GL_TEXTURE_COORD_ARRAY_BUFFER_BINDING', 0x889A )
GL_EDGE_FLAG_ARRAY_BUFFER_BINDING = constant.Constant( 'GL_EDGE_FLAG_ARRAY_BUFFER_BINDING', 0x889B )
GL_SECONDARY_COLOR_ARRAY_BUFFER_BINDING = constant.Constant( 'GL_SECONDARY_COLOR_ARRAY_BUFFER_BINDING', 0x889C )
GL_FOG_COORDINATE_ARRAY_BUFFER_BINDING = constant.Constant( 'GL_FOG_COORDINATE_ARRAY_BUFFER_BINDING', 0x889D )
GL_WEIGHT_ARRAY_BUFFER_BINDING = constant.Constant( 'GL_WEIGHT_ARRAY_BUFFER_BINDING', 0x889E )
GL_FOG_COORD_SRC = constant.Constant( 'GL_FOG_COORD_SRC', 0x8450 )
GL_FOG_COORD = constant.Constant( 'GL_FOG_COORD', 0x8451 )
GL_CURRENT_FOG_COORD = constant.Constant( 'GL_CURRENT_FOG_COORD', 0x8453 )
GL_FOG_COORD_ARRAY_TYPE = constant.Constant( 'GL_FOG_COORD_ARRAY_TYPE', 0x8454 )
GL_FOG_COORD_ARRAY_STRIDE = constant.Constant( 'GL_FOG_COORD_ARRAY_STRIDE', 0x8455 )
GL_FOG_COORD_ARRAY_POINTER = constant.Constant( 'GL_FOG_COORD_ARRAY_POINTER', 0x8456 )
GL_FOG_COORD_ARRAY = constant.Constant( 'GL_FOG_COORD_ARRAY', 0x8457 )
GL_FOG_COORD_ARRAY_BUFFER_BINDING = constant.Constant( 'GL_FOG_COORD_ARRAY_BUFFER_BINDING', 0x889D )
GL_SRC0_RGB = constant.Constant( 'GL_SRC0_RGB', 0x8580 )
GL_SRC1_RGB = constant.Constant( 'GL_SRC1_RGB', 0x8581 )
GL_SRC2_RGB = constant.Constant( 'GL_SRC2_RGB', 0x8582 )
GL_SRC0_ALPHA = constant.Constant( 'GL_SRC0_ALPHA', 0x8588 )
GL_SRC1_ALPHA = constant.Constant( 'GL_SRC1_ALPHA', 0x8589 )
GL_SRC2_ALPHA = constant.Constant( 'GL_SRC2_ALPHA', 0x858A )




'''OpenGL extension ARB.occlusion_query

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_ARB_occlusion_query'
_DEPRECATED = False
GL_QUERY_COUNTER_BITS_ARB = constant.Constant( 'GL_QUERY_COUNTER_BITS_ARB', 0x8864 )
GL_CURRENT_QUERY_ARB = constant.Constant( 'GL_CURRENT_QUERY_ARB', 0x8865 )
GL_QUERY_RESULT_ARB = constant.Constant( 'GL_QUERY_RESULT_ARB', 0x8866 )
GL_QUERY_RESULT_AVAILABLE_ARB = constant.Constant( 'GL_QUERY_RESULT_AVAILABLE_ARB', 0x8867 )
GL_SAMPLES_PASSED_ARB = constant.Constant( 'GL_SAMPLES_PASSED_ARB', 0x8914 )
glGenQueriesARB = platform.createExtensionFunction( 
'glGenQueriesARB',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLsizei,arrays.GLuintArray,),
doc='glGenQueriesARB(GLsizei(n), GLuintArray(ids)) -> None',
argNames=('n','ids',),
deprecated=_DEPRECATED,
)

glDeleteQueriesARB = platform.createExtensionFunction( 
'glDeleteQueriesARB',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLsizei,arrays.GLuintArray,),
doc='glDeleteQueriesARB(GLsizei(n), GLuintArray(ids)) -> None',
argNames=('n','ids',),
deprecated=_DEPRECATED,
)

glIsQueryARB = platform.createExtensionFunction( 
'glIsQueryARB',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=constants.GLboolean, 
argTypes=(constants.GLuint,),
doc='glIsQueryARB(GLuint(id)) -> constants.GLboolean',
argNames=('id',),
deprecated=_DEPRECATED,
)

glBeginQueryARB = platform.createExtensionFunction( 
'glBeginQueryARB',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,),
doc='glBeginQueryARB(GLenum(target), GLuint(id)) -> None',
argNames=('target','id',),
deprecated=_DEPRECATED,
)

glEndQueryARB = platform.createExtensionFunction( 
'glEndQueryARB',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,),
doc='glEndQueryARB(GLenum(target)) -> None',
argNames=('target',),
deprecated=_DEPRECATED,
)

glGetQueryivARB = platform.createExtensionFunction( 
'glGetQueryivARB',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,arrays.GLintArray,),
doc='glGetQueryivARB(GLenum(target), GLenum(pname), GLintArray(params)) -> None',
argNames=('target','pname','params',),
deprecated=_DEPRECATED,
)

glGetQueryObjectivARB = platform.createExtensionFunction( 
'glGetQueryObjectivARB',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,arrays.GLintArray,),
doc='glGetQueryObjectivARB(GLuint(id), GLenum(pname), GLintArray(params)) -> None',
argNames=('id','pname','params',),
deprecated=_DEPRECATED,
)

glGetQueryObjectuivARB = platform.createExtensionFunction( 
'glGetQueryObjectuivARB',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,arrays.GLuintArray,),
doc='glGetQueryObjectuivARB(GLuint(id), GLenum(pname), GLuintArray(params)) -> None',
argNames=('id','pname','params',),
deprecated=_DEPRECATED,
)


def glInitOcclusionQueryARB():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension MESA.pack_invert

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_MESA_pack_invert'
_DEPRECATED = False
GL_PACK_INVERT_MESA = constant.Constant( 'GL_PACK_INVERT_MESA', 0x8758 )
glget.addGLGetConstant( GL_PACK_INVERT_MESA, (1,) )


def glInitPackInvertMESA():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension NV.primitive_restart

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_NV_primitive_restart'
_DEPRECATED = False
GL_PRIMITIVE_RESTART_NV = constant.Constant( 'GL_PRIMITIVE_RESTART_NV', 0x8558 )
glget.addGLGetConstant( GL_PRIMITIVE_RESTART_NV, (1,) )
GL_PRIMITIVE_RESTART_INDEX_NV = constant.Constant( 'GL_PRIMITIVE_RESTART_INDEX_NV', 0x8559 )
glget.addGLGetConstant( GL_PRIMITIVE_RESTART_INDEX_NV, (1,) )
glPrimitiveRestartNV = platform.createExtensionFunction( 
'glPrimitiveRestartNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(),
doc='glPrimitiveRestartNV() -> None',
argNames=(),
deprecated=_DEPRECATED,
)

glPrimitiveRestartIndexNV = platform.createExtensionFunction( 
'glPrimitiveRestartIndexNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,),
doc='glPrimitiveRestartIndexNV(GLuint(index)) -> None',
argNames=('index',),
deprecated=_DEPRECATED,
)


def glInitPrimitiveRestartNV():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension EXT.pixel_buffer_object

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_EXT_pixel_buffer_object'
_DEPRECATED = False
GL_PIXEL_PACK_BUFFER_EXT = constant.Constant( 'GL_PIXEL_PACK_BUFFER_EXT', 0x88EB )
GL_PIXEL_UNPACK_BUFFER_EXT = constant.Constant( 'GL_PIXEL_UNPACK_BUFFER_EXT', 0x88EC )
GL_PIXEL_PACK_BUFFER_BINDING_EXT = constant.Constant( 'GL_PIXEL_PACK_BUFFER_BINDING_EXT', 0x88ED )
glget.addGLGetConstant( GL_PIXEL_PACK_BUFFER_BINDING_EXT, (1,) )
GL_PIXEL_UNPACK_BUFFER_BINDING_EXT = constant.Constant( 'GL_PIXEL_UNPACK_BUFFER_BINDING_EXT', 0x88EF )
glget.addGLGetConstant( GL_PIXEL_UNPACK_BUFFER_BINDING_EXT, (1,) )


def glInitPixelBufferObjectEXT():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



"""Extension module support methods

This module provides the tools required to check whether
an extension is available
"""
from OpenGL.latebind import LateBind
import logging
log = logging.getLogger( 'OpenGL.extensions' )
VERSION_PREFIX = 'GL_VERSION_GL_'
CURRENT_GL_VERSION = None
AVAILABLE_GL_EXTENSIONS = []
AVAILABLE_GLU_EXTENSIONS = []

def getGLVersion( ):
    """Retrieve 2-int declaration of major/minor GL version

    returns [int(major),int(minor)] or False if not loaded
    """
    global CURRENT_GL_VERSION
    if not CURRENT_GL_VERSION:
        from OpenGL.GL import glGetString, GL_VERSION
        new = glGetString( GL_VERSION )
        log.info( 'OpenGL Version: %s', new )
        if new:
            CURRENT_GL_VERSION = [
                int(x) for x in new.split(' ',1)[0].split( '.' )
            ]
        else:
            return False # not yet loaded/supported
    return CURRENT_GL_VERSION


def hasGLExtension( specifier ):
    """Given a string specifier, check for extension being available"""
    global AVAILABLE_GL_EXTENSIONS
    specifier = specifier.replace('.','_')
    if specifier.startswith( VERSION_PREFIX ):
        specifier = [
            int(x)
            for x in specifier[ len(VERSION_PREFIX):].split('_')
        ]
        version = getGLVersion()
        if not version:
            return version
        return specifier <= version
    else:
        from OpenGL.GL import glGetString, GL_EXTENSIONS
        if not AVAILABLE_GL_EXTENSIONS:
            AVAILABLE_GL_EXTENSIONS[:] = glGetString( GL_EXTENSIONS ).split()
        result = specifier in AVAILABLE_GL_EXTENSIONS
        log.info(
            'GL Extension %s %s',
            specifier,
            ['unavailable','available'][bool(result)]
        )
        return result

def hasGLUExtension( specifier ):
    """Given a string specifier, check for extension being available"""
    from OpenGL.GLU import gluGetString, GLU_EXTENSIONS
    if not AVAILABLE_GLU_EXTENSIONS:
        AVAILABLE_GLU_EXTENSIONS[:] = gluGetString( GLU_EXTENSIONS )
    return specifier.replace('.','_') in AVAILABLE_GLU_EXTENSIONS

class _Alternate( LateBind ):
    def __init__( self, name, *alternates ):
        """Initialize set of alternative implementations of the same function"""
        self.__name__ = name
        self._alternatives = alternates
    def __nonzero__( self ):
        from OpenGL import error
        try:
            return bool( self.getFinalCall())
        except error.NullFunctionError, err:
            return False
    def finalise( self ):
        """Call, doing a late lookup and bind to find an implementation"""
        for alternate in self._alternatives:
            if alternate:
                log.info(
                    """Chose alternate: %s from %s""",
                    alternate.__name__,
                    ", ".join([x.__name__ for x in self._alternatives])
                )
                return alternate
        from OpenGL import error
        raise error.NullFunctionError(
            """Attempt to call an undefined alternate function (%s), check for bool(%s) before calling"""%(
                ', '.join([x.__name__ for x in self._alternatives]),
                self.__name__,
            )
        )
def alternate( name, *functions ):
    """Construct a callable that functions as the first implementation found of given set of alternatives

    if name is a function then its name will be used....
    """
    if not isinstance( name, (str,unicode)):
        functions = (name,)+functions
        name = name.__name__
    return type( name, (_Alternate,), {} )( name, *functions )



'''OpenGL extension ARB.sample_shading

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_ARB_sample_shading'
_DEPRECATED = False
GL_SAMPLE_SHADING = constant.Constant( 'GL_SAMPLE_SHADING', 0x8C36 )
GL_MIN_SAMPLE_SHADING_VALUE = constant.Constant( 'GL_MIN_SAMPLE_SHADING_VALUE', 0x8C37 )
glMinSampleShading = platform.createExtensionFunction( 
'glMinSampleShading',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLclampf,),
doc='glMinSampleShading(GLclampf(value)) -> None',
argNames=('value',),
deprecated=_DEPRECATED,
)


def glInitSampleShadingARB():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



# BEGIN GENERATED CONTENT (do not edit below this line)

# This content is generated by gengl.py.
# Wrapper for http://oss.sgi.com/projects/ogl-sample/ABI/glxext.h
from OpenGL import platform, constant
from ctypes import *
c_void = None


# H (/usr/include/GL/glx.h:26)
# GLXEXT_LEGACY (/usr/include/GL/glx.h:298)
GLX_GLXEXT_VERSION = constant.Constant( 'GLX_GLXEXT_VERSION', 11 )
# VERSION_1_3 (GL/glxext.h:59)
# VERSION_1_4 (GL/glxext.h:118)
# ARB_get_proc_address (GL/glxext.h:123)
# ARB_multisample (GL/glxext.h:126)
GLX_SAMPLE_BUFFERS_ARB = constant.Constant( 'GLX_SAMPLE_BUFFERS_ARB', 100000 )
GLX_SAMPLES_ARB = constant.Constant( 'GLX_SAMPLES_ARB', 100001 )
# ARB_fbconfig_float (GL/glxext.h:131)
GLX_RGBA_FLOAT_TYPE_ARB = constant.Constant( 'GLX_RGBA_FLOAT_TYPE_ARB', 8377 )
GLX_RGBA_FLOAT_BIT_ARB = constant.Constant( 'GLX_RGBA_FLOAT_BIT_ARB', 4 )
# SGIS_multisample (GL/glxext.h:136)
GLX_SAMPLE_BUFFERS_SGIS = constant.Constant( 'GLX_SAMPLE_BUFFERS_SGIS', 100000 )
GLX_SAMPLES_SGIS = constant.Constant( 'GLX_SAMPLES_SGIS', 100001 )
# EXT_visual_info (GL/glxext.h:141)
GLX_X_VISUAL_TYPE_EXT = constant.Constant( 'GLX_X_VISUAL_TYPE_EXT', 34 )
GLX_TRANSPARENT_TYPE_EXT = constant.Constant( 'GLX_TRANSPARENT_TYPE_EXT', 35 )
GLX_TRANSPARENT_INDEX_VALUE_EXT = constant.Constant( 'GLX_TRANSPARENT_INDEX_VALUE_EXT', 36 )
GLX_TRANSPARENT_RED_VALUE_EXT = constant.Constant( 'GLX_TRANSPARENT_RED_VALUE_EXT', 37 )
GLX_TRANSPARENT_GREEN_VALUE_EXT = constant.Constant( 'GLX_TRANSPARENT_GREEN_VALUE_EXT', 38 )
GLX_TRANSPARENT_BLUE_VALUE_EXT = constant.Constant( 'GLX_TRANSPARENT_BLUE_VALUE_EXT', 39 )
GLX_TRANSPARENT_ALPHA_VALUE_EXT = constant.Constant( 'GLX_TRANSPARENT_ALPHA_VALUE_EXT', 40 )
GLX_NONE_EXT = constant.Constant( 'GLX_NONE_EXT', 32768 )
GLX_TRUE_COLOR_EXT = constant.Constant( 'GLX_TRUE_COLOR_EXT', 32770 )
GLX_DIRECT_COLOR_EXT = constant.Constant( 'GLX_DIRECT_COLOR_EXT', 32771 )
GLX_PSEUDO_COLOR_EXT = constant.Constant( 'GLX_PSEUDO_COLOR_EXT', 32772 )
GLX_STATIC_COLOR_EXT = constant.Constant( 'GLX_STATIC_COLOR_EXT', 32773 )
GLX_GRAY_SCALE_EXT = constant.Constant( 'GLX_GRAY_SCALE_EXT', 32774 )
GLX_STATIC_GRAY_EXT = constant.Constant( 'GLX_STATIC_GRAY_EXT', 32775 )
GLX_TRANSPARENT_RGB_EXT = constant.Constant( 'GLX_TRANSPARENT_RGB_EXT', 32776 )
GLX_TRANSPARENT_INDEX_EXT = constant.Constant( 'GLX_TRANSPARENT_INDEX_EXT', 32777 )
# SGI_swap_control (GL/glxext.h:160)
# SGI_video_sync (GL/glxext.h:163)
# SGI_make_current_read (GL/glxext.h:166)
# SGIX_video_source (GL/glxext.h:169)
# EXT_visual_rating (GL/glxext.h:172)
GLX_VISUAL_CAVEAT_EXT = constant.Constant( 'GLX_VISUAL_CAVEAT_EXT', 32 )
GLX_SLOW_VISUAL_EXT = constant.Constant( 'GLX_SLOW_VISUAL_EXT', 32769 )
GLX_NON_CONFORMANT_VISUAL_EXT = constant.Constant( 'GLX_NON_CONFORMANT_VISUAL_EXT', 32781 )
# EXT_import_context (GL/glxext.h:179)
GLX_SHARE_CONTEXT_EXT = constant.Constant( 'GLX_SHARE_CONTEXT_EXT', 32778 )
GLX_VISUAL_ID_EXT = constant.Constant( 'GLX_VISUAL_ID_EXT', 32779 )
GLX_SCREEN_EXT = constant.Constant( 'GLX_SCREEN_EXT', 32780 )
# SGIX_fbconfig (GL/glxext.h:185)
GLX_WINDOW_BIT_SGIX = constant.Constant( 'GLX_WINDOW_BIT_SGIX', 1 )
GLX_PIXMAP_BIT_SGIX = constant.Constant( 'GLX_PIXMAP_BIT_SGIX', 2 )
GLX_RGBA_BIT_SGIX = constant.Constant( 'GLX_RGBA_BIT_SGIX', 1 )
GLX_COLOR_INDEX_BIT_SGIX = constant.Constant( 'GLX_COLOR_INDEX_BIT_SGIX', 2 )
GLX_DRAWABLE_TYPE_SGIX = constant.Constant( 'GLX_DRAWABLE_TYPE_SGIX', 32784 )
GLX_RENDER_TYPE_SGIX = constant.Constant( 'GLX_RENDER_TYPE_SGIX', 32785 )
GLX_X_RENDERABLE_SGIX = constant.Constant( 'GLX_X_RENDERABLE_SGIX', 32786 )
GLX_FBCONFIG_ID_SGIX = constant.Constant( 'GLX_FBCONFIG_ID_SGIX', 32787 )
GLX_RGBA_TYPE_SGIX = constant.Constant( 'GLX_RGBA_TYPE_SGIX', 32788 )
GLX_COLOR_INDEX_TYPE_SGIX = constant.Constant( 'GLX_COLOR_INDEX_TYPE_SGIX', 32789 )
# SGIX_pbuffer (GL/glxext.h:199)
GLX_PBUFFER_BIT_SGIX = constant.Constant( 'GLX_PBUFFER_BIT_SGIX', 4 )
GLX_BUFFER_CLOBBER_MASK_SGIX = constant.Constant( 'GLX_BUFFER_CLOBBER_MASK_SGIX', 134217728 )
GLX_FRONT_LEFT_BUFFER_BIT_SGIX = constant.Constant( 'GLX_FRONT_LEFT_BUFFER_BIT_SGIX', 1 )
GLX_FRONT_RIGHT_BUFFER_BIT_SGIX = constant.Constant( 'GLX_FRONT_RIGHT_BUFFER_BIT_SGIX', 2 )
GLX_BACK_LEFT_BUFFER_BIT_SGIX = constant.Constant( 'GLX_BACK_LEFT_BUFFER_BIT_SGIX', 4 )
GLX_BACK_RIGHT_BUFFER_BIT_SGIX = constant.Constant( 'GLX_BACK_RIGHT_BUFFER_BIT_SGIX', 8 )
GLX_AUX_BUFFERS_BIT_SGIX = constant.Constant( 'GLX_AUX_BUFFERS_BIT_SGIX', 16 )
GLX_DEPTH_BUFFER_BIT_SGIX = constant.Constant( 'GLX_DEPTH_BUFFER_BIT_SGIX', 32 )
GLX_STENCIL_BUFFER_BIT_SGIX = constant.Constant( 'GLX_STENCIL_BUFFER_BIT_SGIX', 64 )
GLX_ACCUM_BUFFER_BIT_SGIX = constant.Constant( 'GLX_ACCUM_BUFFER_BIT_SGIX', 128 )
GLX_SAMPLE_BUFFERS_BIT_SGIX = constant.Constant( 'GLX_SAMPLE_BUFFERS_BIT_SGIX', 256 )
GLX_MAX_PBUFFER_WIDTH_SGIX = constant.Constant( 'GLX_MAX_PBUFFER_WIDTH_SGIX', 32790 )
GLX_MAX_PBUFFER_HEIGHT_SGIX = constant.Constant( 'GLX_MAX_PBUFFER_HEIGHT_SGIX', 32791 )
GLX_MAX_PBUFFER_PIXELS_SGIX = constant.Constant( 'GLX_MAX_PBUFFER_PIXELS_SGIX', 32792 )
GLX_OPTIMAL_PBUFFER_WIDTH_SGIX = constant.Constant( 'GLX_OPTIMAL_PBUFFER_WIDTH_SGIX', 32793 )
GLX_OPTIMAL_PBUFFER_HEIGHT_SGIX = constant.Constant( 'GLX_OPTIMAL_PBUFFER_HEIGHT_SGIX', 32794 )
GLX_PRESERVED_CONTENTS_SGIX = constant.Constant( 'GLX_PRESERVED_CONTENTS_SGIX', 32795 )
GLX_LARGEST_PBUFFER_SGIX = constant.Constant( 'GLX_LARGEST_PBUFFER_SGIX', 32796 )
GLX_WIDTH_SGIX = constant.Constant( 'GLX_WIDTH_SGIX', 32797 )
GLX_HEIGHT_SGIX = constant.Constant( 'GLX_HEIGHT_SGIX', 32798 )
GLX_EVENT_MASK_SGIX = constant.Constant( 'GLX_EVENT_MASK_SGIX', 32799 )
GLX_DAMAGED_SGIX = constant.Constant( 'GLX_DAMAGED_SGIX', 32800 )
GLX_SAVED_SGIX = constant.Constant( 'GLX_SAVED_SGIX', 32801 )
GLX_WINDOW_SGIX = constant.Constant( 'GLX_WINDOW_SGIX', 32802 )
GLX_PBUFFER_SGIX = constant.Constant( 'GLX_PBUFFER_SGIX', 32803 )
# SGI_cushion (GL/glxext.h:227)
# SGIX_video_resize (GL/glxext.h:230)
GLX_SYNC_FRAME_SGIX = constant.Constant( 'GLX_SYNC_FRAME_SGIX', 0 )
GLX_SYNC_SWAP_SGIX = constant.Constant( 'GLX_SYNC_SWAP_SGIX', 1 )
# SGIX_dmbuffer (GL/glxext.h:235)
GLX_DIGITAL_MEDIA_PBUFFER_SGIX = constant.Constant( 'GLX_DIGITAL_MEDIA_PBUFFER_SGIX', 32804 )
# SGIX_swap_group (GL/glxext.h:239)
# SGIX_swap_barrier (GL/glxext.h:242)
# SGIS_blended_overlay (GL/glxext.h:245)
GLX_BLENDED_RGBA_SGIS = constant.Constant( 'GLX_BLENDED_RGBA_SGIS', 32805 )
# SGIS_shared_multisample (GL/glxext.h:249)
GLX_MULTISAMPLE_SUB_RECT_WIDTH_SGIS = constant.Constant( 'GLX_MULTISAMPLE_SUB_RECT_WIDTH_SGIS', 32806 )
GLX_MULTISAMPLE_SUB_RECT_HEIGHT_SGIS = constant.Constant( 'GLX_MULTISAMPLE_SUB_RECT_HEIGHT_SGIS', 32807 )
# SUN_get_transparent_index (GL/glxext.h:254)
# 3DFX_multisample (GL/glxext.h:257)
GLX_SAMPLE_BUFFERS_3DFX = constant.Constant( 'GLX_SAMPLE_BUFFERS_3DFX', 32848 )
GLX_SAMPLES_3DFX = constant.Constant( 'GLX_SAMPLES_3DFX', 32849 )
# MESA_copy_sub_buffer (GL/glxext.h:262)
# MESA_pixmap_colormap (GL/glxext.h:265)
# MESA_release_buffers (GL/glxext.h:268)
# MESA_set_3dfx_mode (GL/glxext.h:271)
GLX_3DFX_WINDOW_MODE_MESA = constant.Constant( 'GLX_3DFX_WINDOW_MODE_MESA', 1 )
GLX_3DFX_FULLSCREEN_MODE_MESA = constant.Constant( 'GLX_3DFX_FULLSCREEN_MODE_MESA', 2 )
# SGIX_visual_select_group (GL/glxext.h:276)
GLX_VISUAL_SELECT_GROUP_SGIX = constant.Constant( 'GLX_VISUAL_SELECT_GROUP_SGIX', 32808 )
# OML_swap_method (GL/glxext.h:280)
GLX_SWAP_METHOD_OML = constant.Constant( 'GLX_SWAP_METHOD_OML', 32864 )
GLX_SWAP_EXCHANGE_OML = constant.Constant( 'GLX_SWAP_EXCHANGE_OML', 32865 )
GLX_SWAP_COPY_OML = constant.Constant( 'GLX_SWAP_COPY_OML', 32866 )
GLX_SWAP_UNDEFINED_OML = constant.Constant( 'GLX_SWAP_UNDEFINED_OML', 32867 )
# OML_sync_control (GL/glxext.h:287)
# NV_float_buffer (GL/glxext.h:290)
GLX_FLOAT_COMPONENTS_NV = constant.Constant( 'GLX_FLOAT_COMPONENTS_NV', 8368 )
# SGIX_hyperpipe (GL/glxext.h:294)
GLX_HYPERPIPE_PIPE_NAME_LENGTH_SGIX = constant.Constant( 'GLX_HYPERPIPE_PIPE_NAME_LENGTH_SGIX', 80 )
GLX_BAD_HYPERPIPE_CONFIG_SGIX = constant.Constant( 'GLX_BAD_HYPERPIPE_CONFIG_SGIX', 91 )
GLX_BAD_HYPERPIPE_SGIX = constant.Constant( 'GLX_BAD_HYPERPIPE_SGIX', 92 )
GLX_HYPERPIPE_DISPLAY_PIPE_SGIX = constant.Constant( 'GLX_HYPERPIPE_DISPLAY_PIPE_SGIX', 1 )
GLX_HYPERPIPE_RENDER_PIPE_SGIX = constant.Constant( 'GLX_HYPERPIPE_RENDER_PIPE_SGIX', 2 )
GLX_PIPE_RECT_SGIX = constant.Constant( 'GLX_PIPE_RECT_SGIX', 1 )
GLX_PIPE_RECT_LIMITS_SGIX = constant.Constant( 'GLX_PIPE_RECT_LIMITS_SGIX', 2 )
GLX_HYPERPIPE_STEREO_SGIX = constant.Constant( 'GLX_HYPERPIPE_STEREO_SGIX', 3 )
GLX_HYPERPIPE_PIXEL_AVERAGE_SGIX = constant.Constant( 'GLX_HYPERPIPE_PIXEL_AVERAGE_SGIX', 4 )
GLX_HYPERPIPE_ID_SGIX = constant.Constant( 'GLX_HYPERPIPE_ID_SGIX', 32816 )
# MESA_agp_offset (GL/glxext.h:307)
# ARB_get_proc_address (GL/glxext.h:313)
# SGIX_video_source (GL/glxext.h:317)
# SGIX_fbconfig (GL/glxext.h:321)
# SGIX_pbuffer (GL/glxext.h:326)
# VERSION_1_3 (GL/glxext.h:358)
# VERSION_1_4 (GL/glxext.h:400)
# ARB_get_proc_address (GL/glxext.h:408)
GLX_ARB_get_proc_address = constant.Constant( 'GLX_ARB_get_proc_address', 1 )
__GLXextFuncPtr = CFUNCTYPE(None) 	# GL/glxext.h:314
GLubyte = c_ubyte 	# /usr/include/GL/gl.h:154
glXGetProcAddressARB = platform.createBaseFunction(
    'glXGetProcAddressARB', dll=platform.GL, resultType=__GLXextFuncPtr, 
    argTypes=[POINTER(GLubyte)],
    doc='glXGetProcAddressARB( POINTER(GLubyte)() ) -> __GLXextFuncPtr', 
    argNames=[''],
)

# ARB_multisample (GL/glxext.h:416)
GLX_ARB_multisample = constant.Constant( 'GLX_ARB_multisample', 1 )
# ARB_fbconfig_float (GL/glxext.h:420)
GLX_ARB_fbconfig_float = constant.Constant( 'GLX_ARB_fbconfig_float', 1 )
# SGIS_multisample (GL/glxext.h:424)
GLX_SGIS_multisample = constant.Constant( 'GLX_SGIS_multisample', 1 )
# EXT_visual_info (GL/glxext.h:428)
GLX_EXT_visual_info = constant.Constant( 'GLX_EXT_visual_info', 1 )
# SGI_swap_control (GL/glxext.h:432)
GLX_SGI_swap_control = constant.Constant( 'GLX_SGI_swap_control', 1 )
glXSwapIntervalSGI = platform.createBaseFunction(
    'glXSwapIntervalSGI', dll=platform.GL, resultType=c_int, 
    argTypes=[c_int],
    doc='glXSwapIntervalSGI( c_int(None) ) -> c_int', 
    argNames=['None'],
)

# SGI_video_sync (GL/glxext.h:440)
GLX_SGI_video_sync = constant.Constant( 'GLX_SGI_video_sync', 1 )
glXGetVideoSyncSGI = platform.createBaseFunction(
    'glXGetVideoSyncSGI', dll=platform.GL, resultType=c_int, 
    argTypes=[POINTER(c_uint)],
    doc='glXGetVideoSyncSGI( POINTER(c_uint)() ) -> c_int', 
    argNames=[''],
)

glXWaitVideoSyncSGI = platform.createBaseFunction(
    'glXWaitVideoSyncSGI', dll=platform.GL, resultType=c_int, 
    argTypes=[c_int, c_int, POINTER(c_uint)],
    doc='glXWaitVideoSyncSGI( c_int(None), c_int(None), POINTER(c_uint)() ) -> c_int', 
    argNames=['None', 'None', ''],
)

# SGI_make_current_read (GL/glxext.h:450)
GLX_SGI_make_current_read = constant.Constant( 'GLX_SGI_make_current_read', 1 )
class struct__XDisplay(Structure):
    __slots__ = [
    ]
struct__XDisplay._fields_ = [
    ('_opaque_struct', c_int)
]

class struct__XDisplay(Structure):
    __slots__ = [
    ]
struct__XDisplay._fields_ = [
    ('_opaque_struct', c_int)
]

Display = struct__XDisplay 	# /usr/include/X11/Xlib.h:519
XID = c_ulong 	# /usr/include/X11/X.h:71
GLXDrawable = XID 	# /usr/include/GL/glx.h:180
class struct___GLXcontextRec(Structure):
    __slots__ = [
    ]
struct___GLXcontextRec._fields_ = [
    ('_opaque_struct', c_int)
]

class struct___GLXcontextRec(Structure):
    __slots__ = [
    ]
struct___GLXcontextRec._fields_ = [
    ('_opaque_struct', c_int)
]

GLXContext = POINTER(struct___GLXcontextRec) 	# /usr/include/GL/glx.h:178
glXMakeCurrentReadSGI = platform.createBaseFunction(
    'glXMakeCurrentReadSGI', dll=platform.GL, resultType=c_int, 
    argTypes=[POINTER(Display), GLXDrawable, GLXDrawable, GLXContext],
    doc='glXMakeCurrentReadSGI( POINTER(Display)(), GLXDrawable(None), GLXDrawable(None), GLXContext(None) ) -> c_int', 
    argNames=['', 'None', 'None', 'None'],
)

glXGetCurrentReadDrawableSGI = platform.createBaseFunction(
    'glXGetCurrentReadDrawableSGI', dll=platform.GL, resultType=GLXDrawable, 
    argTypes=[],
    doc='glXGetCurrentReadDrawableSGI(  ) -> GLXDrawable', 
    argNames=[],
)

# SGIX_video_source (GL/glxext.h:460)
GLX_SGIX_video_source = constant.Constant( 'GLX_SGIX_video_source', 1 )
# EXT_visual_rating (GL/glxext.h:472)
GLX_EXT_visual_rating = constant.Constant( 'GLX_EXT_visual_rating', 1 )
# EXT_import_context (GL/glxext.h:476)
GLX_EXT_import_context = constant.Constant( 'GLX_EXT_import_context', 1 )
glXGetCurrentDisplayEXT = platform.createBaseFunction(
    'glXGetCurrentDisplayEXT', dll=platform.GL, resultType=POINTER(Display), 
    argTypes=[],
    doc='glXGetCurrentDisplayEXT(  ) -> POINTER(Display)', 
    argNames=[],
)

glXQueryContextInfoEXT = platform.createBaseFunction(
    'glXQueryContextInfoEXT', dll=platform.GL, resultType=c_int, 
    argTypes=[POINTER(Display), GLXContext, c_int, POINTER(c_int)],
    doc='glXQueryContextInfoEXT( POINTER(Display)(), GLXContext(None), c_int(None), POINTER(c_int)() ) -> c_int', 
    argNames=['', 'None', 'None', ''],
)

GLXContextID = XID 	# /usr/include/GL/glx.h:184
glXGetContextIDEXT = platform.createBaseFunction(
    'glXGetContextIDEXT', dll=platform.GL, resultType=GLXContextID, 
    argTypes=[GLXContext],
    doc='glXGetContextIDEXT( GLXContext(None) ) -> GLXContextID', 
    argNames=['None'],
)

glXImportContextEXT = platform.createBaseFunction(
    'glXImportContextEXT', dll=platform.GL, resultType=GLXContext, 
    argTypes=[POINTER(Display), GLXContextID],
    doc='glXImportContextEXT( POINTER(Display)(), GLXContextID(None) ) -> GLXContext', 
    argNames=['', 'None'],
)

glXFreeContextEXT = platform.createBaseFunction(
    'glXFreeContextEXT', dll=platform.GL, resultType=None, 
    argTypes=[POINTER(Display), GLXContext],
    doc='glXFreeContextEXT( POINTER(Display)(), GLXContext(None) ) -> None', 
    argNames=['', 'None'],
)

# SGIX_fbconfig (GL/glxext.h:492)
GLX_SGIX_fbconfig = constant.Constant( 'GLX_SGIX_fbconfig', 1 )
class struct___GLXFBConfigRec(Structure):
    __slots__ = [
    ]
struct___GLXFBConfigRec._fields_ = [
    ('_opaque_struct', c_int)
]

class struct___GLXFBConfigRec(Structure):
    __slots__ = [
    ]
struct___GLXFBConfigRec._fields_ = [
    ('_opaque_struct', c_int)
]

GLXFBConfigSGIX = POINTER(struct___GLXFBConfigRec) 	# GL/glxext.h:323
glXGetFBConfigAttribSGIX = platform.createBaseFunction(
    'glXGetFBConfigAttribSGIX', dll=platform.GL, resultType=c_int, 
    argTypes=[POINTER(Display), GLXFBConfigSGIX, c_int, POINTER(c_int)],
    doc='glXGetFBConfigAttribSGIX( POINTER(Display)(), GLXFBConfigSGIX(None), c_int(None), POINTER(c_int)() ) -> c_int', 
    argNames=['', 'None', 'None', ''],
)

glXChooseFBConfigSGIX = platform.createBaseFunction(
    'glXChooseFBConfigSGIX', dll=platform.GL, resultType=POINTER(GLXFBConfigSGIX), 
    argTypes=[POINTER(Display), c_int, POINTER(c_int), POINTER(c_int)],
    doc='glXChooseFBConfigSGIX( POINTER(Display)(), c_int(None), POINTER(c_int)(), POINTER(c_int)() ) -> POINTER(GLXFBConfigSGIX)', 
    argNames=['', 'None', '', ''],
)

GLXPixmap = XID 	# /usr/include/GL/glx.h:179
Pixmap = XID 	# /usr/include/X11/X.h:107
glXCreateGLXPixmapWithConfigSGIX = platform.createBaseFunction(
    'glXCreateGLXPixmapWithConfigSGIX', dll=platform.GL, resultType=GLXPixmap, 
    argTypes=[POINTER(Display), GLXFBConfigSGIX, Pixmap],
    doc='glXCreateGLXPixmapWithConfigSGIX( POINTER(Display)(), GLXFBConfigSGIX(None), Pixmap(None) ) -> GLXPixmap', 
    argNames=['', 'None', 'None'],
)

glXCreateContextWithConfigSGIX = platform.createBaseFunction(
    'glXCreateContextWithConfigSGIX', dll=platform.GL, resultType=GLXContext, 
    argTypes=[POINTER(Display), GLXFBConfigSGIX, c_int, GLXContext, c_int],
    doc='glXCreateContextWithConfigSGIX( POINTER(Display)(), GLXFBConfigSGIX(None), c_int(None), GLXContext(None), c_int(None) ) -> GLXContext', 
    argNames=['', 'None', 'None', 'None', 'None'],
)

class struct_anon_208(Structure):
    __slots__ = [
        'visual',
        'visualid',
        'screen',
        'depth',
        'class',
        'red_mask',
        'green_mask',
        'blue_mask',
        'colormap_size',
        'bits_per_rgb',
    ]
class struct_anon_125(Structure):
    __slots__ = [
        'ext_data',
        'visualid',
        'class',
        'red_mask',
        'green_mask',
        'blue_mask',
        'bits_per_rgb',
        'map_entries',
    ]
class struct__XExtData(Structure):
    __slots__ = [
        'number',
        'next',
        'free_private',
        'private_data',
    ]
XPointer = c_char_p 	# /usr/include/X11/Xlib.h:108
struct__XExtData._fields_ = [
    ('number', c_int),
    ('next', POINTER(struct__XExtData)),
    ('free_private', POINTER(CFUNCTYPE(c_int, POINTER(struct__XExtData)))),
    ('private_data', XPointer),
]

XExtData = struct__XExtData 	# /usr/include/X11/Xlib.h:187
VisualID = c_ulong 	# /usr/include/X11/X.h:81
struct_anon_125._fields_ = [
    ('ext_data', POINTER(XExtData)),
    ('visualid', VisualID),
    ('class', c_int),
    ('red_mask', c_ulong),
    ('green_mask', c_ulong),
    ('blue_mask', c_ulong),
    ('bits_per_rgb', c_int),
    ('map_entries', c_int),
]

Visual = struct_anon_125 	# /usr/include/X11/Xlib.h:270
struct_anon_208._fields_ = [
    ('visual', POINTER(Visual)),
    ('visualid', VisualID),
    ('screen', c_int),
    ('depth', c_int),
    ('class', c_int),
    ('red_mask', c_ulong),
    ('green_mask', c_ulong),
    ('blue_mask', c_ulong),
    ('colormap_size', c_int),
    ('bits_per_rgb', c_int),
]

XVisualInfo = struct_anon_208 	# /usr/include/X11/Xutil.h:296
glXGetVisualFromFBConfigSGIX = platform.createBaseFunction(
    'glXGetVisualFromFBConfigSGIX', dll=platform.GL, resultType=POINTER(XVisualInfo), 
    argTypes=[POINTER(Display), GLXFBConfigSGIX],
    doc='glXGetVisualFromFBConfigSGIX( POINTER(Display)(), GLXFBConfigSGIX(None) ) -> POINTER(XVisualInfo)', 
    argNames=['', 'None'],
)

glXGetFBConfigFromVisualSGIX = platform.createBaseFunction(
    'glXGetFBConfigFromVisualSGIX', dll=platform.GL, resultType=GLXFBConfigSGIX, 
    argTypes=[POINTER(Display), POINTER(XVisualInfo)],
    doc='glXGetFBConfigFromVisualSGIX( POINTER(Display)(), POINTER(XVisualInfo)() ) -> GLXFBConfigSGIX', 
    argNames=['', ''],
)

# SGIX_pbuffer (GL/glxext.h:510)
GLX_SGIX_pbuffer = constant.Constant( 'GLX_SGIX_pbuffer', 1 )
GLXPbufferSGIX = XID 	# GL/glxext.h:327
glXCreateGLXPbufferSGIX = platform.createBaseFunction(
    'glXCreateGLXPbufferSGIX', dll=platform.GL, resultType=GLXPbufferSGIX, 
    argTypes=[POINTER(Display), GLXFBConfigSGIX, c_uint, c_uint, POINTER(c_int)],
    doc='glXCreateGLXPbufferSGIX( POINTER(Display)(), GLXFBConfigSGIX(None), c_uint(None), c_uint(None), POINTER(c_int)() ) -> GLXPbufferSGIX', 
    argNames=['', 'None', 'None', 'None', ''],
)

glXDestroyGLXPbufferSGIX = platform.createBaseFunction(
    'glXDestroyGLXPbufferSGIX', dll=platform.GL, resultType=None, 
    argTypes=[POINTER(Display), GLXPbufferSGIX],
    doc='glXDestroyGLXPbufferSGIX( POINTER(Display)(), GLXPbufferSGIX(None) ) -> None', 
    argNames=['', 'None'],
)

glXQueryGLXPbufferSGIX = platform.createBaseFunction(
    'glXQueryGLXPbufferSGIX', dll=platform.GL, resultType=c_int, 
    argTypes=[POINTER(Display), GLXPbufferSGIX, c_int, POINTER(c_uint)],
    doc='glXQueryGLXPbufferSGIX( POINTER(Display)(), GLXPbufferSGIX(None), c_int(None), POINTER(c_uint)() ) -> c_int', 
    argNames=['', 'None', 'None', ''],
)

glXSelectEventSGIX = platform.createBaseFunction(
    'glXSelectEventSGIX', dll=platform.GL, resultType=None, 
    argTypes=[POINTER(Display), GLXDrawable, c_ulong],
    doc='glXSelectEventSGIX( POINTER(Display)(), GLXDrawable(None), c_ulong(None) ) -> None', 
    argNames=['', 'None', 'None'],
)

glXGetSelectedEventSGIX = platform.createBaseFunction(
    'glXGetSelectedEventSGIX', dll=platform.GL, resultType=None, 
    argTypes=[POINTER(Display), GLXDrawable, POINTER(c_ulong)],
    doc='glXGetSelectedEventSGIX( POINTER(Display)(), GLXDrawable(None), POINTER(c_ulong)() ) -> None', 
    argNames=['', 'None', ''],
)

# SGI_cushion (GL/glxext.h:526)
GLX_SGI_cushion = constant.Constant( 'GLX_SGI_cushion', 1 )
Window = XID 	# /usr/include/X11/X.h:101
glXCushionSGI = platform.createBaseFunction(
    'glXCushionSGI', dll=platform.GL, resultType=None, 
    argTypes=[POINTER(Display), Window, c_float],
    doc='glXCushionSGI( POINTER(Display)(), Window(None), c_float(None) ) -> None', 
    argNames=['', 'None', 'None'],
)

# SGIX_video_resize (GL/glxext.h:534)
GLX_SGIX_video_resize = constant.Constant( 'GLX_SGIX_video_resize', 1 )
glXBindChannelToWindowSGIX = platform.createBaseFunction(
    'glXBindChannelToWindowSGIX', dll=platform.GL, resultType=c_int, 
    argTypes=[POINTER(Display), c_int, c_int, Window],
    doc='glXBindChannelToWindowSGIX( POINTER(Display)(), c_int(None), c_int(None), Window(None) ) -> c_int', 
    argNames=['', 'None', 'None', 'None'],
)

glXChannelRectSGIX = platform.createBaseFunction(
    'glXChannelRectSGIX', dll=platform.GL, resultType=c_int, 
    argTypes=[POINTER(Display), c_int, c_int, c_int, c_int, c_int, c_int],
    doc='glXChannelRectSGIX( POINTER(Display)(), c_int(None), c_int(None), c_int(None), c_int(None), c_int(None), c_int(None) ) -> c_int', 
    argNames=['', 'None', 'None', 'None', 'None', 'None', 'None'],
)

glXQueryChannelRectSGIX = platform.createBaseFunction(
    'glXQueryChannelRectSGIX', dll=platform.GL, resultType=c_int, 
    argTypes=[POINTER(Display), c_int, c_int, POINTER(c_int), POINTER(c_int), POINTER(c_int), POINTER(c_int)],
    doc='glXQueryChannelRectSGIX( POINTER(Display)(), c_int(None), c_int(None), POINTER(c_int)(), POINTER(c_int)(), POINTER(c_int)(), POINTER(c_int)() ) -> c_int', 
    argNames=['', 'None', 'None', '', '', '', ''],
)

glXQueryChannelDeltasSGIX = platform.createBaseFunction(
    'glXQueryChannelDeltasSGIX', dll=platform.GL, resultType=c_int, 
    argTypes=[POINTER(Display), c_int, c_int, POINTER(c_int), POINTER(c_int), POINTER(c_int), POINTER(c_int)],
    doc='glXQueryChannelDeltasSGIX( POINTER(Display)(), c_int(None), c_int(None), POINTER(c_int)(), POINTER(c_int)(), POINTER(c_int)(), POINTER(c_int)() ) -> c_int', 
    argNames=['', 'None', 'None', '', '', '', ''],
)

GLenum = c_uint 	# /usr/include/GL/gl.h:147
glXChannelRectSyncSGIX = platform.createBaseFunction(
    'glXChannelRectSyncSGIX', dll=platform.GL, resultType=c_int, 
    argTypes=[POINTER(Display), c_int, c_int, GLenum],
    doc='glXChannelRectSyncSGIX( POINTER(Display)(), c_int(None), c_int(None), GLenum(None) ) -> c_int', 
    argNames=['', 'None', 'None', 'None'],
)

# SGIX_dmbuffer (GL/glxext.h:550)
GLX_SGIX_dmbuffer = constant.Constant( 'GLX_SGIX_dmbuffer', 1 )
# SGIX_swap_group (GL/glxext.h:560)
GLX_SGIX_swap_group = constant.Constant( 'GLX_SGIX_swap_group', 1 )
glXJoinSwapGroupSGIX = platform.createBaseFunction(
    'glXJoinSwapGroupSGIX', dll=platform.GL, resultType=None, 
    argTypes=[POINTER(Display), GLXDrawable, GLXDrawable],
    doc='glXJoinSwapGroupSGIX( POINTER(Display)(), GLXDrawable(None), GLXDrawable(None) ) -> None', 
    argNames=['', 'None', 'None'],
)

# SGIX_swap_barrier (GL/glxext.h:568)
GLX_SGIX_swap_barrier = constant.Constant( 'GLX_SGIX_swap_barrier', 1 )
glXBindSwapBarrierSGIX = platform.createBaseFunction(
    'glXBindSwapBarrierSGIX', dll=platform.GL, resultType=None, 
    argTypes=[POINTER(Display), GLXDrawable, c_int],
    doc='glXBindSwapBarrierSGIX( POINTER(Display)(), GLXDrawable(None), c_int(None) ) -> None', 
    argNames=['', 'None', 'None'],
)

glXQueryMaxSwapBarriersSGIX = platform.createBaseFunction(
    'glXQueryMaxSwapBarriersSGIX', dll=platform.GL, resultType=c_int, 
    argTypes=[POINTER(Display), c_int, POINTER(c_int)],
    doc='glXQueryMaxSwapBarriersSGIX( POINTER(Display)(), c_int(None), POINTER(c_int)() ) -> c_int', 
    argNames=['', 'None', ''],
)

# SUN_get_transparent_index (GL/glxext.h:578)
GLX_SUN_get_transparent_index = constant.Constant( 'GLX_SUN_get_transparent_index', 1 )
glXGetTransparentIndexSUN = platform.createBaseFunction(
    'glXGetTransparentIndexSUN', dll=platform.GL, resultType=c_int, 
    argTypes=[POINTER(Display), Window, Window, POINTER(c_long)],
    doc='glXGetTransparentIndexSUN( POINTER(Display)(), Window(None), Window(None), POINTER(c_long)() ) -> c_int', 
    argNames=['', 'None', 'None', ''],
)

# MESA_copy_sub_buffer (GL/glxext.h:586)
GLX_MESA_copy_sub_buffer = constant.Constant( 'GLX_MESA_copy_sub_buffer', 1 )
glXCopySubBufferMESA = platform.createBaseFunction(
    'glXCopySubBufferMESA', dll=platform.GL, resultType=None, 
    argTypes=[POINTER(Display), GLXDrawable, c_int, c_int, c_int, c_int],
    doc='glXCopySubBufferMESA( POINTER(Display)(), GLXDrawable(None), c_int(None), c_int(None), c_int(None), c_int(None) ) -> None', 
    argNames=['', 'None', 'None', 'None', 'None', 'None'],
)

# MESA_pixmap_colormap (GL/glxext.h:594)
GLX_MESA_pixmap_colormap = constant.Constant( 'GLX_MESA_pixmap_colormap', 1 )
Colormap = XID 	# /usr/include/X11/X.h:109
glXCreateGLXPixmapMESA = platform.createBaseFunction(
    'glXCreateGLXPixmapMESA', dll=platform.GL, resultType=GLXPixmap, 
    argTypes=[POINTER(Display), POINTER(XVisualInfo), Pixmap, Colormap],
    doc='glXCreateGLXPixmapMESA( POINTER(Display)(), POINTER(XVisualInfo)(), Pixmap(None), Colormap(None) ) -> GLXPixmap', 
    argNames=['', '', 'None', 'None'],
)

# MESA_release_buffers (GL/glxext.h:602)
GLX_MESA_release_buffers = constant.Constant( 'GLX_MESA_release_buffers', 1 )
glXReleaseBuffersMESA = platform.createBaseFunction(
    'glXReleaseBuffersMESA', dll=platform.GL, resultType=c_int, 
    argTypes=[POINTER(Display), GLXDrawable],
    doc='glXReleaseBuffersMESA( POINTER(Display)(), GLXDrawable(None) ) -> c_int', 
    argNames=['', 'None'],
)

# MESA_set_3dfx_mode (GL/glxext.h:610)
GLX_MESA_set_3dfx_mode = constant.Constant( 'GLX_MESA_set_3dfx_mode', 1 )
glXSet3DfxModeMESA = platform.createBaseFunction(
    'glXSet3DfxModeMESA', dll=platform.GL, resultType=c_int, 
    argTypes=[c_int],
    doc='glXSet3DfxModeMESA( c_int(None) ) -> c_int', 
    argNames=['None'],
)

# SGIX_visual_select_group (GL/glxext.h:618)
GLX_SGIX_visual_select_group = constant.Constant( 'GLX_SGIX_visual_select_group', 1 )
# OML_swap_method (GL/glxext.h:622)
GLX_OML_swap_method = constant.Constant( 'GLX_OML_swap_method', 1 )
# OML_sync_control (GL/glxext.h:626)
GLX_OML_sync_control = constant.Constant( 'GLX_OML_sync_control', 1 )
glXGetSyncValuesOML = platform.createBaseFunction(
    'glXGetSyncValuesOML', dll=platform.GL, resultType=c_int, 
    argTypes=[POINTER(Display), GLXDrawable, POINTER(c_int64), POINTER(c_int64), POINTER(c_int64)],
    doc='glXGetSyncValuesOML( POINTER(Display)(), GLXDrawable(None), POINTER(c_int64)(), POINTER(c_int64)(), POINTER(c_int64)() ) -> c_int', 
    argNames=['', 'None', '', '', ''],
)

glXGetMscRateOML = platform.createBaseFunction(
    'glXGetMscRateOML', dll=platform.GL, resultType=c_int, 
    argTypes=[POINTER(Display), GLXDrawable, POINTER(c_int32), POINTER(c_int32)],
    doc='glXGetMscRateOML( POINTER(Display)(), GLXDrawable(None), POINTER(c_int32)(), POINTER(c_int32)() ) -> c_int', 
    argNames=['', 'None', '', ''],
)

glXSwapBuffersMscOML = platform.createBaseFunction(
    'glXSwapBuffersMscOML', dll=platform.GL, resultType=c_int64, 
    argTypes=[POINTER(Display), GLXDrawable, c_int64, c_int64, c_int64],
    doc='glXSwapBuffersMscOML( POINTER(Display)(), GLXDrawable(None), c_int64(None), c_int64(None), c_int64(None) ) -> c_int64', 
    argNames=['', 'None', 'None', 'None', 'None'],
)

glXWaitForMscOML = platform.createBaseFunction(
    'glXWaitForMscOML', dll=platform.GL, resultType=c_int, 
    argTypes=[POINTER(Display), GLXDrawable, c_int64, c_int64, c_int64, POINTER(c_int64), POINTER(c_int64), POINTER(c_int64)],
    doc='glXWaitForMscOML( POINTER(Display)(), GLXDrawable(None), c_int64(None), c_int64(None), c_int64(None), POINTER(c_int64)(), POINTER(c_int64)(), POINTER(c_int64)() ) -> c_int', 
    argNames=['', 'None', 'None', 'None', 'None', '', '', ''],
)

glXWaitForSbcOML = platform.createBaseFunction(
    'glXWaitForSbcOML', dll=platform.GL, resultType=c_int, 
    argTypes=[POINTER(Display), GLXDrawable, c_int64, POINTER(c_int64), POINTER(c_int64), POINTER(c_int64)],
    doc='glXWaitForSbcOML( POINTER(Display)(), GLXDrawable(None), c_int64(None), POINTER(c_int64)(), POINTER(c_int64)(), POINTER(c_int64)() ) -> c_int', 
    argNames=['', 'None', 'None', '', '', ''],
)

# NV_float_buffer (GL/glxext.h:642)
GLX_NV_float_buffer = constant.Constant( 'GLX_NV_float_buffer', 1 )
# SGIX_hyperpipe (GL/glxext.h:646)
GLX_SGIX_hyperpipe = constant.Constant( 'GLX_SGIX_hyperpipe', 1 )
class struct_anon_212(Structure):
    __slots__ = [
        'pipeName',
        'networkId',
    ]
struct_anon_212._fields_ = [
    ('pipeName', c_char * 80),
    ('networkId', c_int),
]

GLXHyperpipeNetworkSGIX = struct_anon_212 	# GL/glxext.h:652
glXQueryHyperpipeNetworkSGIX = platform.createBaseFunction(
    'glXQueryHyperpipeNetworkSGIX', dll=platform.GL, resultType=POINTER(GLXHyperpipeNetworkSGIX), 
    argTypes=[POINTER(Display), POINTER(c_int)],
    doc='glXQueryHyperpipeNetworkSGIX( POINTER(Display)(), POINTER(c_int)() ) -> POINTER(GLXHyperpipeNetworkSGIX)', 
    argNames=['', ''],
)

class struct_anon_213(Structure):
    __slots__ = [
        'pipeName',
        'channel',
        'participationType',
        'timeSlice',
    ]
struct_anon_213._fields_ = [
    ('pipeName', c_char * 80),
    ('channel', c_int),
    ('participationType', c_uint),
    ('timeSlice', c_int),
]

GLXHyperpipeConfigSGIX = struct_anon_213 	# GL/glxext.h:660
glXHyperpipeConfigSGIX = platform.createBaseFunction(
    'glXHyperpipeConfigSGIX', dll=platform.GL, resultType=c_int, 
    argTypes=[POINTER(Display), c_int, c_int, POINTER(GLXHyperpipeConfigSGIX), POINTER(c_int)],
    doc='glXHyperpipeConfigSGIX( POINTER(Display)(), c_int(None), c_int(None), POINTER(GLXHyperpipeConfigSGIX)(), POINTER(c_int)() ) -> c_int', 
    argNames=['', 'None', 'None', '', ''],
)

glXQueryHyperpipeConfigSGIX = platform.createBaseFunction(
    'glXQueryHyperpipeConfigSGIX', dll=platform.GL, resultType=POINTER(GLXHyperpipeConfigSGIX), 
    argTypes=[POINTER(Display), c_int, POINTER(c_int)],
    doc='glXQueryHyperpipeConfigSGIX( POINTER(Display)(), c_int(None), POINTER(c_int)() ) -> POINTER(GLXHyperpipeConfigSGIX)', 
    argNames=['', 'None', ''],
)

glXDestroyHyperpipeConfigSGIX = platform.createBaseFunction(
    'glXDestroyHyperpipeConfigSGIX', dll=platform.GL, resultType=c_int, 
    argTypes=[POINTER(Display), c_int],
    doc='glXDestroyHyperpipeConfigSGIX( POINTER(Display)(), c_int(None) ) -> c_int', 
    argNames=['', 'None'],
)

glXBindHyperpipeSGIX = platform.createBaseFunction(
    'glXBindHyperpipeSGIX', dll=platform.GL, resultType=c_int, 
    argTypes=[POINTER(Display), c_int],
    doc='glXBindHyperpipeSGIX( POINTER(Display)(), c_int(None) ) -> c_int', 
    argNames=['', 'None'],
)

glXQueryHyperpipeBestAttribSGIX = platform.createBaseFunction(
    'glXQueryHyperpipeBestAttribSGIX', dll=platform.GL, resultType=c_int, 
    argTypes=[POINTER(Display), c_int, c_int, c_int, POINTER(None), POINTER(None)],
    doc='glXQueryHyperpipeBestAttribSGIX( POINTER(Display)(), c_int(None), c_int(None), c_int(None), POINTER(None)(), POINTER(None)() ) -> c_int', 
    argNames=['', 'None', 'None', 'None', '', ''],
)

glXHyperpipeAttribSGIX = platform.createBaseFunction(
    'glXHyperpipeAttribSGIX', dll=platform.GL, resultType=c_int, 
    argTypes=[POINTER(Display), c_int, c_int, c_int, POINTER(None)],
    doc='glXHyperpipeAttribSGIX( POINTER(Display)(), c_int(None), c_int(None), c_int(None), POINTER(None)() ) -> c_int', 
    argNames=['', 'None', 'None', 'None', ''],
)

glXQueryHyperpipeAttribSGIX = platform.createBaseFunction(
    'glXQueryHyperpipeAttribSGIX', dll=platform.GL, resultType=c_int, 
    argTypes=[POINTER(Display), c_int, c_int, c_int, POINTER(None)],
    doc='glXQueryHyperpipeAttribSGIX( POINTER(Display)(), c_int(None), c_int(None), c_int(None), POINTER(None)() ) -> c_int', 
    argNames=['', 'None', 'None', 'None', ''],
)

# MESA_agp_offset (GL/glxext.h:693)
GLX_MESA_agp_offset = constant.Constant( 'GLX_MESA_agp_offset', 1 )
glXGetAGPOffsetMESA = platform.createBaseFunction(
    'glXGetAGPOffsetMESA', dll=platform.GL, resultType=c_uint, 
    argTypes=[POINTER(None)],
    doc='glXGetAGPOffsetMESA( POINTER(None)() ) -> c_uint', 
    argNames=[''],
)

# NV_vertex_array_range (/usr/include/GL/glx.h:330)
# MESA_allocate_memory (/usr/include/GL/glx.h:344)
# ARB_render_texture (/usr/include/GL/glx.h:361)
# NV_float_buffer (/usr/include/GL/glx.h:374)
# MESA_swap_frame_usage (/usr/include/GL/glx.h:386)
# MESA_swap_control (/usr/include/GL/glx.h:406)
# EXT_texture_from_pixmap (/usr/include/GL/glx.h:423)

__all__ = ['GLX_GLXEXT_VERSION', 'GLX_SAMPLE_BUFFERS_ARB', 'GLX_SAMPLES_ARB',
'GLX_RGBA_FLOAT_TYPE_ARB', 'GLX_RGBA_FLOAT_BIT_ARB',
'GLX_SAMPLE_BUFFERS_SGIS', 'GLX_SAMPLES_SGIS', 'GLX_X_VISUAL_TYPE_EXT',
'GLX_TRANSPARENT_TYPE_EXT', 'GLX_TRANSPARENT_INDEX_VALUE_EXT',
'GLX_TRANSPARENT_RED_VALUE_EXT', 'GLX_TRANSPARENT_GREEN_VALUE_EXT',
'GLX_TRANSPARENT_BLUE_VALUE_EXT', 'GLX_TRANSPARENT_ALPHA_VALUE_EXT',
'GLX_NONE_EXT', 'GLX_TRUE_COLOR_EXT', 'GLX_DIRECT_COLOR_EXT',
'GLX_PSEUDO_COLOR_EXT', 'GLX_STATIC_COLOR_EXT', 'GLX_GRAY_SCALE_EXT',
'GLX_STATIC_GRAY_EXT', 'GLX_TRANSPARENT_RGB_EXT', 'GLX_TRANSPARENT_INDEX_EXT',
'GLX_VISUAL_CAVEAT_EXT', 'GLX_SLOW_VISUAL_EXT',
'GLX_NON_CONFORMANT_VISUAL_EXT', 'GLX_SHARE_CONTEXT_EXT', 'GLX_VISUAL_ID_EXT',
'GLX_SCREEN_EXT', 'GLX_WINDOW_BIT_SGIX', 'GLX_PIXMAP_BIT_SGIX',
'GLX_RGBA_BIT_SGIX', 'GLX_COLOR_INDEX_BIT_SGIX', 'GLX_DRAWABLE_TYPE_SGIX',
'GLX_RENDER_TYPE_SGIX', 'GLX_X_RENDERABLE_SGIX', 'GLX_FBCONFIG_ID_SGIX',
'GLX_RGBA_TYPE_SGIX', 'GLX_COLOR_INDEX_TYPE_SGIX', 'GLX_PBUFFER_BIT_SGIX',
'GLX_BUFFER_CLOBBER_MASK_SGIX', 'GLX_FRONT_LEFT_BUFFER_BIT_SGIX',
'GLX_FRONT_RIGHT_BUFFER_BIT_SGIX', 'GLX_BACK_LEFT_BUFFER_BIT_SGIX',
'GLX_BACK_RIGHT_BUFFER_BIT_SGIX', 'GLX_AUX_BUFFERS_BIT_SGIX',
'GLX_DEPTH_BUFFER_BIT_SGIX', 'GLX_STENCIL_BUFFER_BIT_SGIX',
'GLX_ACCUM_BUFFER_BIT_SGIX', 'GLX_SAMPLE_BUFFERS_BIT_SGIX',
'GLX_MAX_PBUFFER_WIDTH_SGIX', 'GLX_MAX_PBUFFER_HEIGHT_SGIX',
'GLX_MAX_PBUFFER_PIXELS_SGIX', 'GLX_OPTIMAL_PBUFFER_WIDTH_SGIX',
'GLX_OPTIMAL_PBUFFER_HEIGHT_SGIX', 'GLX_PRESERVED_CONTENTS_SGIX',
'GLX_LARGEST_PBUFFER_SGIX', 'GLX_WIDTH_SGIX', 'GLX_HEIGHT_SGIX',
'GLX_EVENT_MASK_SGIX', 'GLX_DAMAGED_SGIX', 'GLX_SAVED_SGIX',
'GLX_WINDOW_SGIX', 'GLX_PBUFFER_SGIX', 'GLX_SYNC_FRAME_SGIX',
'GLX_SYNC_SWAP_SGIX', 'GLX_DIGITAL_MEDIA_PBUFFER_SGIX',
'GLX_BLENDED_RGBA_SGIS', 'GLX_MULTISAMPLE_SUB_RECT_WIDTH_SGIS',
'GLX_MULTISAMPLE_SUB_RECT_HEIGHT_SGIS', 'GLX_SAMPLE_BUFFERS_3DFX',
'GLX_SAMPLES_3DFX', 'GLX_3DFX_WINDOW_MODE_MESA',
'GLX_3DFX_FULLSCREEN_MODE_MESA', 'GLX_VISUAL_SELECT_GROUP_SGIX',
'GLX_SWAP_METHOD_OML', 'GLX_SWAP_EXCHANGE_OML', 'GLX_SWAP_COPY_OML',
'GLX_SWAP_UNDEFINED_OML', 'GLX_FLOAT_COMPONENTS_NV',
'GLX_HYPERPIPE_PIPE_NAME_LENGTH_SGIX', 'GLX_BAD_HYPERPIPE_CONFIG_SGIX',
'GLX_BAD_HYPERPIPE_SGIX', 'GLX_HYPERPIPE_DISPLAY_PIPE_SGIX',
'GLX_HYPERPIPE_RENDER_PIPE_SGIX', 'GLX_PIPE_RECT_SGIX',
'GLX_PIPE_RECT_LIMITS_SGIX', 'GLX_HYPERPIPE_STEREO_SGIX',
'GLX_HYPERPIPE_PIXEL_AVERAGE_SGIX', 'GLX_HYPERPIPE_ID_SGIX',
'GLX_ARB_get_proc_address', 'glXGetProcAddressARB', 'GLX_ARB_multisample',
'GLX_ARB_fbconfig_float', 'GLX_SGIS_multisample', 'GLX_EXT_visual_info',
'GLX_SGI_swap_control', 'glXSwapIntervalSGI', 'GLX_SGI_video_sync',
'glXGetVideoSyncSGI', 'glXWaitVideoSyncSGI', 'GLX_SGI_make_current_read',
'glXMakeCurrentReadSGI', 'glXGetCurrentReadDrawableSGI',
'GLX_SGIX_video_source', 'GLX_EXT_visual_rating', 'GLX_EXT_import_context',
'glXGetCurrentDisplayEXT', 'glXQueryContextInfoEXT', 'glXGetContextIDEXT',
'glXImportContextEXT', 'glXFreeContextEXT', 'GLX_SGIX_fbconfig',
'glXGetFBConfigAttribSGIX', 'glXChooseFBConfigSGIX',
'glXCreateGLXPixmapWithConfigSGIX', 'glXCreateContextWithConfigSGIX',
'glXGetVisualFromFBConfigSGIX', 'glXGetFBConfigFromVisualSGIX',
'GLX_SGIX_pbuffer', 'glXCreateGLXPbufferSGIX', 'glXDestroyGLXPbufferSGIX',
'glXQueryGLXPbufferSGIX', 'glXSelectEventSGIX', 'glXGetSelectedEventSGIX',
'GLX_SGI_cushion', 'glXCushionSGI', 'GLX_SGIX_video_resize',
'glXBindChannelToWindowSGIX', 'glXChannelRectSGIX', 'glXQueryChannelRectSGIX',
'glXQueryChannelDeltasSGIX', 'glXChannelRectSyncSGIX', 'GLX_SGIX_dmbuffer',
'GLX_SGIX_swap_group', 'glXJoinSwapGroupSGIX', 'GLX_SGIX_swap_barrier',
'glXBindSwapBarrierSGIX', 'glXQueryMaxSwapBarriersSGIX',
'GLX_SUN_get_transparent_index', 'glXGetTransparentIndexSUN',
'GLX_MESA_copy_sub_buffer', 'glXCopySubBufferMESA',
'GLX_MESA_pixmap_colormap', 'glXCreateGLXPixmapMESA',
'GLX_MESA_release_buffers', 'glXReleaseBuffersMESA', 'GLX_MESA_set_3dfx_mode',
'glXSet3DfxModeMESA', 'GLX_SGIX_visual_select_group', 'GLX_OML_swap_method',
'GLX_OML_sync_control', 'glXGetSyncValuesOML', 'glXGetMscRateOML',
'glXSwapBuffersMscOML', 'glXWaitForMscOML', 'glXWaitForSbcOML',
'GLX_NV_float_buffer', 'GLX_SGIX_hyperpipe', 'glXQueryHyperpipeNetworkSGIX',
'glXHyperpipeConfigSGIX', 'glXQueryHyperpipeConfigSGIX',
'glXDestroyHyperpipeConfigSGIX', 'glXBindHyperpipeSGIX',
'glXQueryHyperpipeBestAttribSGIX', 'glXHyperpipeAttribSGIX',
'glXQueryHyperpipeAttribSGIX', 'GLX_MESA_agp_offset', 'glXGetAGPOffsetMESA']
# END GENERATED CONTENT (do not edit above this line)

